@@ -3,6 +3,7 @@ import json
 import os
 import pathlib
 import re
+import textwrap
 import time
 import traceback
 
@@ -29,7 +30,7 @@ __author__ = "Gavin Huttley"
 __copyright__ = "Copyright 2007-2020, The Cogent Project"
 __credits__ = ["Gavin Huttley"]
 __license__ = "BSD-3"
-__version__ = "2020.2.7a"
+__version__ = "2020.12.21a"
 __maintainer__ = "Gavin Huttley"
 __email__ = "Gavin.Huttley@anu.edu.au"
 __status__ = "Alpha"
@@ -62,11 +63,7 @@ def _get_source(source):
 
 
 def _get_origin(origin):
-    if type(origin) == str:
-        result = origin
-    else:
-        result = origin.__class__.__name__
-    return result
+    return origin if type(origin) == str else origin.__class__.__name__
 
 
 class NotCompleted(int):
@@ -187,11 +184,7 @@ class ComposableType:
             return True
 
         name = data.__class__.__name__
-        valid = False
-        for type_ in self._data_types:
-            if type_ == name:
-                valid = True
-                break
+        valid = name in self._data_types
         if not valid:
             msg = f"invalid data type, '{name}' not in {', '.join(self._data_types)}"
             valid = NotCompleted("ERROR", self, message=msg, source=data)
@@ -214,6 +207,7 @@ class Composable(ComposableType):
         if txt:
             txt += " + "
         txt += "%s(%s)" % (self.__class__.__name__, ", ".join(self._formatted))
+        txt = textwrap.fill(txt, width=80, break_long_words=False)
         return txt
 
     def __repr__(self):
@@ -434,8 +428,8 @@ class Composable(ComposableType):
             LOGGER.log_file_path = logger
         elif logger == True:
             log_file_path = pathlib.Path(_make_logfile_name(self))
-            source = pathlib.Path(self.data_store.source)
-            log_file_path = source.parent / log_file_path
+            src = pathlib.Path(self.data_store.source)
+            log_file_path = src.parent / log_file_path
             LOGGER = scitrack.CachingLogger()
             LOGGER.log_file_path = str(log_file_path)
         else:
@@ -464,15 +458,21 @@ class Composable(ComposableType):
             outcome = result if process is self else self(result)
             results.append(outcome)
             if LOGGER:
-                member = dstore[i]
+                member = todo[i]
                 # ensure member is a DataStoreMember instance
                 if not isinstance(member, DataStoreMember):
                     member = SingleReadDataStore(member)[0]
 
+                mem_id = self.data_store.make_relative_identifier(member.name)
+                src = self.data_store.make_relative_identifier(result)
+                assert (
+                    src == mem_id
+                ), f"mismatched input data and result identifiers: {src} != {mem_id}"
+
                 LOGGER.log_message(member, label="input")
                 if member.md5:
                     LOGGER.log_message(member.md5, label="input md5sum")
-                mem_id = self.data_store.make_relative_identifier(member.name)
+
                 if outcome:
                     member = self.data_store.get_member(mem_id)
                     LOGGER.log_message(member, label="output")
@@ -612,6 +612,8 @@ class _checkpointable(Composable):
         super(_checkpointable, self).__init__(**kwargs)
         self._formatted_params()
 
+        data_path = str(data_path)
+
         if data_path.endswith(".tinydb") and not self.__class__.__name__.endswith("db"):
             raise ValueError("tinydb suffix reserved for write_db")
 
