@@ -10,6 +10,7 @@ import zipfile
 from collections import defaultdict
 from fnmatch import fnmatch, translate
 from io import TextIOWrapper
+from json import JSONDecodeError
 from pathlib import Path
 from pprint import pprint
 from warnings import warn
@@ -34,7 +35,7 @@ __author__ = "Gavin Huttley"
 __copyright__ = "Copyright 2007-2020, The Cogent Project"
 __credits__ = ["Gavin Huttley"]
 __license__ = "BSD-3"
-__version__ = "2020.2.7a"
+__version__ = "2020.12.21a"
 __maintainer__ = "Gavin Huttley"
 __email__ = "Gavin.Huttley@anu.edu.au"
 __status__ = "Alpha"
@@ -55,15 +56,21 @@ def make_record_for_json(identifier, data, completed):
         pass
 
     data = json.dumps(data)
-    record = dict(identifier=identifier, data=data, completed=completed)
-    return record
+    return dict(identifier=identifier, data=data, completed=completed)
 
 
 def load_record_from_json(data):
     """returns identifier, data, completed status from json string"""
     if type(data) == str:
         data = json.loads(data)
-    value = json.loads(data["data"])
+
+    value = data["data"]
+    if isinstance(value, str):
+        try:
+            value = json.loads(value)
+        except JSONDecodeError:
+            pass
+
     return data["identifier"], value, data["completed"]
 
 
@@ -126,6 +133,7 @@ class ReadOnlyDataStoreBase:
         d = locals()
         self._persistent = UnionDict({k: v for k, v in d.items() if k != "self"})
 
+        source = str(source)
         suffix = suffix or ""
         if suffix != "*":  # wild card search for all
             suffix = re.sub(r"^[\s.*]+", "", suffix)  # tidy the suffix
@@ -218,8 +226,7 @@ class ReadOnlyDataStoreBase:
         return None
 
     def get_relative_identifier(self, identifier):
-        """returns the identifier relative to store root path
-        """
+        """returns the identifier relative to store root path"""
         if isinstance(identifier, DataStoreMember) and identifier.parent is self:
             return identifier
 
@@ -239,8 +246,7 @@ class ReadOnlyDataStoreBase:
         return identifier
 
     def get_absolute_identifier(self, identifier, from_relative=False):
-        """returns the identifier relative to the root path
-        """
+        """returns the identifier relative to the root path"""
         if not from_relative:
             identifier = self.get_relative_identifier(identifier)
         source = self.source.replace(".zip", "")
@@ -339,7 +345,7 @@ class SingleReadDataStore(ReadOnlyDirectoryDataStore):
         kwargs
             ignored
         """
-        path = Path(source)
+        path = Path(source).expanduser()
         assert path.exists() and path.is_file()
         super(SingleReadDataStore, self).__init__(
             str(path.parent), suffix=str(path.suffix)
@@ -568,7 +574,7 @@ class WritableDirectoryDataStore(ReadOnlyDirectoryDataStore, WritableDataStoreBa
 
     def _has_other_suffixes(self, path, suffix):
         p = Path(path)
-        allowed = {str(suffix), "log"}
+        allowed = {str(suffix).lower(), "log"}
         for f in p.iterdir():
             if get_format_suffixes(str(f))[0] not in allowed:
                 return True
@@ -773,8 +779,7 @@ class ReadOnlyTinyDbDataStore(ReadOnlyDataStoreBase):
         self._finish.detach()
 
     def lock(self):
-        """if writable, and not locked, locks the database to this pid
-        """
+        """if writable, and not locked, locks the database to this pid"""
         if not self.locked:
             self._db.insert(dict(identifier="LOCK", pid=os.getpid()))
             self._db.storage.flush()
@@ -841,7 +846,7 @@ class ReadOnlyTinyDbDataStore(ReadOnlyDataStoreBase):
             ]
             rows.append(row)
 
-        table = Table(header=header, rows=rows, title="incomplete records")
+        table = Table(header=header, data=rows, title="incomplete records")
         return table
 
     @property
@@ -926,8 +931,18 @@ class ReadOnlyTinyDbDataStore(ReadOnlyDataStoreBase):
             data = record.read().splitlines()
             first = data.pop(0).split("\t")
             row = [first[0], record.name]
-            data = [r.split("\t")[-1].split(" : ", maxsplit=1) for r in data]
-            data = dict(data)
+            key = None
+            mapped = {}
+            for line in data:
+                line = line.split("\t")[-1].split(" : ", maxsplit=1)
+                if len(line) == 1:
+                    mapped[key] += line[0]
+                    continue
+
+                key = line[0]
+                mapped[key] = line[1]
+
+            data = mapped
             row.extend(
                 [
                     data["python"],
@@ -939,7 +954,7 @@ class ReadOnlyTinyDbDataStore(ReadOnlyDataStoreBase):
             rows.append(row)
         table = Table(
             header=["time", "name", "python version", "who", "command", "composable"],
-            rows=rows,
+            data=rows,
             title="summary of log files",
         )
         return table
@@ -959,7 +974,7 @@ class ReadOnlyTinyDbDataStore(ReadOnlyDataStoreBase):
         num_logs = len(self.logs)
         summary = Table(
             header=["record type", "number"],
-            rows=[
+            data=[
                 ["completed", num_complete],
                 ["incomplete", num_incomplete],
                 ["logs", num_logs],
@@ -972,7 +987,7 @@ class ReadOnlyTinyDbDataStore(ReadOnlyDataStoreBase):
 class WritableTinyDbDataStore(ReadOnlyTinyDbDataStore, WritableDataStoreBase):
     def __init__(self, *args, **kwargs):
         if_exists = kwargs.pop("if_exists", RAISE)
-        create = kwargs.pop("create", None)
+        create = kwargs.pop("create", True)
         ReadOnlyTinyDbDataStore.__init__(self, *args, **kwargs)
         WritableDataStoreBase.__init__(self, if_exists=if_exists, create=create)
 
