@@ -35,9 +35,10 @@ from numpy import (
 )
 from numpy.random import permutation
 
+import cogent3
+
 from cogent3.core.alphabet import AlphabetError
-from cogent3.core.genetic_code import DEFAULT as DEFAULT_GENETIC_CODE
-from cogent3.core.genetic_code import GeneticCodes
+from cogent3.core.genetic_code import get_code
 from cogent3.core.info import Info as InfoClass
 from cogent3.format.fasta import alignment_to_fasta
 from cogent3.maths.stats.contingency import CategoryCounts, TestResult
@@ -48,6 +49,7 @@ from cogent3.util.misc import (
     DistanceFromMatrix,
     bytes_to_string,
     get_object_provenance,
+    get_setting_from_environ,
 )
 from cogent3.util.transform import (
     KeepChars,
@@ -69,9 +71,9 @@ __credits__ = [
     "Daniel McDonald",
 ]
 __license__ = "BSD-3"
-__version__ = "2020.2.7a"
-__maintainer__ = "Rob Knight"
-__email__ = "rob@spot.colorado.edu"
+__version__ = "2020.12.21a"
+__maintainer__ = "Gavin Huttley"
+__email__ = "Gavin.Huttley@anu.edu.au"
 __status__ = "Production"
 
 ARRAY_TYPE = type(array(1))
@@ -150,7 +152,13 @@ class SequenceI(object):
         return json.dumps(self.to_rich_dict())
 
     def translate(self, *args, **kwargs):
-        """translate() delegates to self._seq."""
+        """returns the result of call str.translate
+
+        Notes
+        -----
+        This is a string method, nothing to do with translating into a
+        protein sequence.
+        """
         return self._seq.translate(*args, **kwargs)
 
     def count(self, item):
@@ -648,6 +656,118 @@ class SequenceI(object):
     def strand_symmetry(self, *args, **kwargs):
         raise TypeError("must be DNA or RNA moltype")
 
+    def _repr_html_(self):
+        settings = self._repr_policy.copy()
+        env_vals = get_setting_from_environ(
+            "COGENT3_ALIGNMENT_REPR_POLICY",
+            dict(num_pos=int),
+        )
+        settings.update(env_vals)
+        return self.to_html(limit=settings["num_pos"])
+
+    def to_html(
+        self,
+        wrap=60,
+        limit=None,
+        colors=None,
+        font_size=12,
+        font_family="Lucida Console",
+        interleave_len=None,
+    ):
+        """returns html with embedded styles for sequence colouring
+
+        Parameters
+        ----------
+        interleave_len
+            replaced by wrap in version 2021.6
+        wrap
+            maximum number of printed bases, defaults to
+            alignment length, old name is interleave_len
+        limit
+            truncate alignment to this length
+        colors
+            {character
+            moltype.
+        font_size
+            in points. Affects labels and sequence and line spacing
+            (proportional to value)
+        font_family
+            string denoting font family
+
+        To display in jupyter notebook:
+
+            >>> from IPython.core.display import HTML
+            >>> HTML(aln.to_html())
+        """
+        if interleave_len is not None:
+            cogent3.util.warning.deprecated(
+                "argument", "interleave_len", "wrap", "2021.6"
+            )
+            wrap = interleave_len if wrap == 60 else wrap
+
+        # todo refactor interleave_len to be wrap
+        css, styles = self.moltype.get_css_style(
+            colors=colors, font_size=font_size, font_family=font_family
+        )
+
+        seq = str(self)
+        seq = seq if limit is None else seq[:limit]
+        gaps = "".join(self.moltype.gaps)
+        seqlen = len(seq)
+        start_gap = re.search("^[%s]+" % gaps, "".join(seq))
+        end_gap = re.search("[%s]+$" % gaps, "".join(seq))
+
+        start = 0 if start_gap is None else start_gap.end()
+        end = len(seq) if end_gap is None else end_gap.start()
+        seq_style = []
+        template = '<span class="%s">%%s</span>'
+        styled_seq = []
+        for i in range(seqlen):
+            char = seq[i]
+            if i < start or i >= end:
+                style = "terminal_ambig_%s" % self.moltype.label
+            else:
+                style = styles[char]
+
+            seq_style.append(template % style)
+            styled_seq.append(seq_style[-1] % char)
+
+        # make a html table
+        seq = array(styled_seq, dtype="O")
+        table = ["<table>"]
+        seq_ = "<td>%s</td>"
+        label_ = '<td class="label">%s</td>'
+        num_row_ = '<tr class="num_row"><td></td><td><b>{:,d}</b></td></tr>'
+        for i in range(0, seqlen, wrap):
+            table.append(num_row_.format(i))
+            seqblock = seq[i : i + wrap].tolist()
+            seqblock = "".join(seqblock)
+            row = "".join([label_ % self.name, seq_ % seqblock])
+            table.append("<tr>%s</tr>" % row)
+        table.append("</table>")
+        class_name = self.__class__.__name__
+        if limit and limit < len(self):
+            summary = f"{len(self)} (truncated to {limit if limit else len(self)}) {class_name}"
+        else:
+            summary = f"{len(self)} {class_name}"
+
+        text = [
+            "<style>",
+            ".c3seq td { border: none !important; text-align: left !important; }",
+            ".c3seq tr:not(.num_row) td span {margin: 0 2px;}",
+            ".c3seq tr:nth-child(even) {background: #f7f7f7;}",
+            ".c3seq .num_row {background-color:rgba(161, 195, 209, 0.5) !important; border-top: solid 1px black; }",
+            ".c3seq .label { font-size: %dpt ; text-align: right !important; "
+            "color: black !important; padding: 0 4px; }" % font_size,
+            "\n".join([".c3seq " + style for style in css]),
+            "</style>",
+            '<div class="c3seq">',
+            "\n".join(table),
+            "<p><i>%s</i></p>" % summary,
+            "</div>",
+        ]
+        return "\n".join(text)
+
 
 @total_ordering
 class Sequence(_Annotatable, SequenceI):
@@ -712,7 +832,10 @@ class Sequence(_Annotatable, SequenceI):
         self.info = info
 
         if isinstance(orig_seq, _Annotatable):
-            self.copy_annotations(orig_seq)
+            for ann in orig_seq.annotations:
+                ann.copy_annotations_to(self)
+
+        self._repr_policy = dict(num_pos=60)
 
     def to_moltype(self, moltype):
         """returns copy of self with moltype seq
@@ -739,12 +862,6 @@ class Sequence(_Annotatable, SequenceI):
         """Returns filtered seq; used to do DNA/RNA conversions."""
         return seq
 
-    def get_colour_scheme(self, colours):
-        return {}
-
-    def get_color_scheme(self, colors):  # alias to support US spelling
-        return self.get_colour_scheme(colours=colors)
-
     def copy_annotations(self, other):
         self.annotations = other.annotations[:]
 
@@ -968,7 +1085,6 @@ class Sequence(_Annotatable, SequenceI):
 
     def gettype(self):
         """Return the sequence type."""
-
         return self.moltype.label
 
     def resolveambiguities(self):
@@ -1092,22 +1208,19 @@ class Sequence(_Annotatable, SequenceI):
 
 
 class ProteinSequence(Sequence):
-    """Holds the standard Protein sequence. MolType set in moltype module."""
+    """Holds the standard Protein sequence."""
 
     pass
 
 
 class ProteinWithStopSequence(Sequence):
-    """Holds the standard Protein sequence, allows for stop codon
-
-    MolType set in moltype module
-    """
+    """Holds the standard Protein sequence, allows for stop codon."""
 
     pass
 
 
 class NucleicAcidSequence(Sequence):
-    """base class for DNA and RNA sequences. Abstract."""
+    """Abstract base class for DNA and RNA sequences."""
 
     PROTEIN = None  # will set in moltype
     codon_alphabet = None  # will set in moltype
@@ -1124,14 +1237,6 @@ class NucleicAcidSequence(Sequence):
         self._annotations_nucleic_reversed_on(rc)
         return rc
 
-    def _gc_from_arg(self, gc):
-        # codon_alphabet is being deprecated in favor of genetic codes.
-        if gc is None:
-            gc = DEFAULT_GENETIC_CODE
-        elif isinstance(gc, (int, str)):
-            gc = GeneticCodes[gc]
-        return gc
-
     def has_terminal_stop(self, gc=None, allow_partial=False):
         """Return True if the sequence has a terminal stop codon.
 
@@ -1144,7 +1249,7 @@ class NucleicAcidSequence(Sequence):
             by 3, ignores the 3' terminal incomplete codon
 
         """
-        gc = self._gc_from_arg(gc)
+        gc = get_code(gc)
         codons = self._seq
         divisible_by_3 = len(codons) % 3 == 0
         end3 = self.__class__(self._seq[-3:]).degap()
@@ -1168,7 +1273,7 @@ class NucleicAcidSequence(Sequence):
             by 3, ignores the 3' terminal incomplete codon
 
         """
-        gc = self._gc_from_arg(gc)
+        gc = get_code(gc)
         codons = self._seq
         divisible_by_3 = len(codons) % 3 == 0
 
@@ -1195,7 +1300,7 @@ class NucleicAcidSequence(Sequence):
         -------
         sequence of PROTEIN moltype
         """
-        gc = self._gc_from_arg(gc)
+        gc = get_code(gc)
         codon_alphabet = self.codon_alphabet(gc).with_gap_motif()
         # translate the codons
         translation = []
@@ -1230,7 +1335,7 @@ class NucleicAcidSequence(Sequence):
         return translation
 
     def get_orf_positions(self, gc=None, atg=False):
-        gc = self._gc_from_arg(gc)
+        gc = get_code(gc)
         orfs = []
         start = None
         protein = self.get_translation(gc=gc)
@@ -1279,13 +1384,7 @@ class NucleicAcidSequence(Sequence):
 
 
 class DnaSequence(NucleicAcidSequence):
-    def get_colour_scheme(self, colours):
-        return {
-            "A": colours.black,
-            "T": colours.red,
-            "C": colours.blue,
-            "G": colours.green,
-        }
+    """Holds the standard DNA sequence."""
 
     def _seq_filter(self, seq):
         """Converts U to T."""
@@ -1293,13 +1392,7 @@ class DnaSequence(NucleicAcidSequence):
 
 
 class RnaSequence(NucleicAcidSequence):
-    def get_colour_scheme(self, colours):
-        return {
-            "A": colours.black,
-            "U": colours.red,
-            "C": colours.blue,
-            "G": colours.green,
-        }
+    """Holds the standard RNA sequence."""
 
     def _seq_filter(self, seq):
         """Converts T to U."""
@@ -1307,7 +1400,7 @@ class RnaSequence(NucleicAcidSequence):
 
 
 class ABSequence(Sequence):
-    """Used for two-state modeling; MolType set in moltypes."""
+    """Holds a two-state sequence, with characters of 'a', 'b'"""
 
     pass
 
@@ -1316,7 +1409,7 @@ class ByteSequence(Sequence):
     """Used for storing arbitrary bytes."""
 
     def __init__(self, seq="", name=None, info=None, check=False, preserve_case=True):
-        return super(ByteSequence, self).__init__(
+        super(ByteSequence, self).__init__(
             seq, name=name, info=info, check=check, preserve_case=preserve_case
         )
 
@@ -1385,6 +1478,7 @@ class ArraySequenceBase(object):
 
         self.moltype = self.alphabet.moltype
         self.info = info
+        self._repr_policy = dict(num_pos=60)
 
     def __getitem__(self, *args):
         """__getitem__ returns char or slice, as same class."""
@@ -1458,8 +1552,8 @@ class ArraySequenceBase(object):
         """iter returns characters of self, rather than slices."""
         if hasattr(self.alphabet, "to_string"):
             return iter(self.alphabet.to_string(self._data))
-        else:
-            return iter(self.Alpabet.from_indices(self._data))
+
+        return iter(self.alpabet.from_indices(self._data))
 
     def tostring(self):
         """to_string delegates to self._data."""
@@ -1615,8 +1709,7 @@ class ArraySequenceBase(object):
         return list(self.gap_array().nonzero()[0])
 
     def frac_same_gaps(self, other):
-        """Returns fraction of positions where gaps match other's gaps.
-        """
+        """Returns fraction of positions where gaps match other's gaps."""
         if not other:
             return 0
         self_gaps = self.gap_array()
