@@ -27,7 +27,7 @@ __author__ = "Sheng Han Moses Koh"
 __copyright__ = "Copyright 2007-2020, The Cogent Project"
 __credits__ = ["Sheng Han Moses Koh", "Gavin Huttley"]
 __license__ = "BSD-3"
-__version__ = "2020.2.7a"
+__version__ = "2020.12.21a"
 __maintainer__ = "Gavin Huttley"
 __email__ = "gavin.huttley@anu.edu.au"
 __status__ = "Alpha"
@@ -275,7 +275,15 @@ _svg_paths = {
             13.816700519612363,
             0.0,
         ],
-        ["C", 7.822582093118824, 0.0, 0.0, 12.142256518341865, 0.0, 49.83879327488448,],
+        [
+            "C",
+            7.822582093118824,
+            0.0,
+            0.0,
+            12.142256518341865,
+            0.0,
+            49.83879327488448,
+        ],
         [
             "C",
             0.0,
@@ -489,7 +497,15 @@ _svg_paths = {
             14.202274496850151,
             0.0,
         ],
-        ["C", 7.788618078002973, 0.0, 0.0, 12.182388391074733, 0.0, 49.10620481899415,],
+        [
+            "C",
+            7.788618078002973,
+            0.0,
+            0.0,
+            12.182388391074733,
+            0.0,
+            49.10620481899415,
+        ],
         [
             "C",
             0.0,
@@ -792,7 +808,15 @@ _svg_paths = {
             12.718800552930814,
             0.0,
         ],
-        ["C", 7.322898967011539, 0.0, 0.0, 12.066392909416166, 0.0, 50.35371605139047,],
+        [
+            "C",
+            7.322898967011539,
+            0.0,
+            0.0,
+            12.066392909416166,
+            0.0,
+            50.35371605139047,
+        ],
         [
             "C",
             0.0,
@@ -1549,13 +1573,20 @@ _svg_paths = {
         ["V", 100.00000000000001],
         ["Z"],
     ],
-    "-": [["M", 0.0, 100.0], ["H", 25.0], ["V", 0.0], ["H", 0.0], ["V", 100.0], ["Z"],],
+    "-": [
+        ["M", 0.0, 100.0],
+        ["H", 25.0],
+        ["V", 0.0],
+        ["H", 0.0],
+        ["V", 100.0],
+        ["Z"],
+    ],
 }
 
 
 def letter_stack(data, x, width, colours, axnum):
     """returns plotly SVG letter shapes with letters stacked on top of each other
-    
+
     Parameters
     ----------
     data
