@@ -11,12 +11,14 @@ from cogent3.util.dict_array import DictArray
 from cogent3.util.misc import get_object_provenance
 from cogent3.util.progress_display import display_wrap
 
+from .pairwise_distance_numba import fill_diversity_matrix
+
 
 __author__ = "Gavin Huttley, Yicheng Zhu and Ben Kaehler"
 __copyright__ = "Copyright 2007-2020, The Cogent Project"
 __credits__ = ["Gavin Huttley", "Yicheng Zhu", "Ben Kaehler"]
 __license__ = "BSD-3"
-__version__ = "2020.2.7a"
+__version__ = "2020.12.21a"
 __maintainer__ = "Gavin Huttley"
 __email__ = "gavin.huttley@anu.edu.au"
 __status__ = "Alpha"  # pending addition of protein distance metrics
@@ -268,14 +270,6 @@ def _logdet(matrix, use_tk_adjustment=True):
     return total, p, d_xy, var
 
 
-try:
-    from ._pairwise_distance import _fill_diversity_matrix as fill_diversity_matrix
-
-    # raise ImportError # for testing
-except ImportError:
-    fill_diversity_matrix = _fill_diversity_matrix
-
-
 def _number_formatter(template):
     """flexible number formatter"""
 
@@ -308,7 +302,9 @@ def _make_stat_table(stats, names, **kwargs):
     for i in range(len(names)):
         rows[i].insert(0, names[i])
 
-    table = Table(header=header, rows=rows, row_ids=True, missing_data="*", **kwargs)
+    table = Table(
+        header=header, data=rows, index_name=r"Seq1 \ Seq2", missing_data="*", **kwargs
+    )
     return table
 
 
@@ -538,7 +534,7 @@ class _PairwiseDistance(object):
 class HammingPair(_PairwiseDistance):
     """Hamming distance calculator for pairwise alignments"""
 
-    valid_moltypes = ("dna", "rna", "protein", "text")
+    valid_moltypes = ("dna", "rna", "protein", "text", "bytes")
 
     def __init__(self, moltype="text", *args, **kwargs):
         """states: the valid sequence states"""
@@ -549,7 +545,7 @@ class HammingPair(_PairwiseDistance):
 class PercentIdentityPair(_PairwiseDistance):
     """Percent identity distance calculator for pairwise alignments"""
 
-    valid_moltypes = ("dna", "rna", "protein", "text")
+    valid_moltypes = ("dna", "rna", "protein", "text", "bytes")
 
     def __init__(self, moltype="text", *args, **kwargs):
         """states: the valid sequence states"""
@@ -639,8 +635,8 @@ class LogDetPair(_PairwiseDistance):
 
     def __init__(self, moltype="dna", use_tk_adjustment=True, *args, **kwargs):
         """Arguments:
-            - moltype: string or moltype instance (must be dna or rna)
-            - use_tk_adjustment: use the correction of Tamura and Kumar 2002
+        - moltype: string or moltype instance (must be dna or rna)
+        - use_tk_adjustment: use the correction of Tamura and Kumar 2002
         """
         super(LogDetPair, self).__init__(moltype, *args, **kwargs)
         self.func = _logdet
@@ -688,7 +684,8 @@ def get_distance_calculator(name, *args, **kwargs):
 
 
 def available_distances():
-    """returns Table listing available pairwise genetic distance calculator
+    """returns Table listing available fast pairwise genetic distance calculator
+
     Notes
     -----
     For more complicated genetic distance methods, see the evolve.models module.
@@ -701,12 +698,12 @@ def available_distances():
 
     table = Table(
         header=["Abbreviation", "Suitable for moltype"],
-        rows=rows,
+        data=rows,
         title=(
             "Specify a pairwise genetic distance calculator "
             "using 'Abbreviation' (case insensitive)."
         ),
-        row_ids=True,
+        index_name="Abbreviation",
     )
     return table
 
@@ -737,6 +734,18 @@ class DistanceMatrix(DictArray):
     def names(self):
         return self.template.names[0]
 
+    def to_table(self):
+        """converted to a Table"""
+        from cogent3.util.table import Table
+
+        data = {"names": self.names}
+        for i, name in enumerate(self.names):
+            column = self.array[:, i]
+            data[name] = column
+        header = ["names"] + list(self.names)
+        table = Table(header=header, data=data, index_name="names")
+        return table
+
     def to_dict(self, **kwargs):
         """Returns a flattened dict with diagonal elements removed"""
         result = super(DistanceMatrix, self).to_dict(flatten=True)
