@@ -9,13 +9,12 @@ __author__ = "Thomas La"
 __copyright__ = "Copyright 2007-2020, The Cogent Project"
 __credits__ = ["Jeremy Widmann", "Rob Knight", "Gavin Huttley", "Thomas La"]
 __license__ = "BSD-3"
-__version__ = "2020.2.7a"
+__version__ = "2020.12.21a"
 __maintainer__ = "Thomas La"
 
 
 def alignment_to_gde(alignment_dict, block_size=60, order=None):
-    """Returns a Gde string given an alignment.
-    """
+    """Returns a Gde string given an alignment."""
     return GDEFormatter().format(
         alignment_dict, block_size, [] if order is None else order
     )
