@@ -11,14 +11,14 @@ import textwrap
 
 from xml.sax.saxutils import escape
 
-from cogent3.util.warning import discontinued
+import numpy
 
 
 __author__ = "Gavin Huttley"
 __copyright__ = "Copyright 2007-2020, The Cogent Project"
 __credits__ = ["Gavin Huttley", "Peter Maxwell", "Matthew Wakefield", "Jeremy Widmann"]
 __license__ = "BSD-3"
-__version__ = "2020.2.7a"
+__version__ = "2020.12.21a"
 __maintainer__ = "Gavin Huttley"
 __email__ = "gavin.huttley@anu.edu.au"
 __status__ = "Production"
@@ -38,6 +38,26 @@ known_formats = (
     "tsv",
 )
 
+css_c3table_template = "\n".join(
+    (
+        ".c3table table {margin: 10px 0;}",
+        ".c3table tr:last-child {border-bottom: 1px solid #000;} ",
+        ".c3table tr > th {text-align: left; padding: 0 5px;}",
+        ".c3table tr > td {text-align: left; padding: 5px;}",
+        ".c3table tr:nth-child(even) {background: #f7f7f7 !important;}",
+        ".c3table .ellipsis {background: rgba(0, 0, 0, .01);}",
+        ".c3table .index {background: %(colour)s; margin: 10px; font-weight: 600;}",
+        ".c3table .head_cell {background: %(head_colour)s; font-weight: bold; text-align: center;}",
+        ".c3table caption {color: rgb(250, 250, 250); background: "
+        "rgba(30, 140, 200, 1); padding: 3px; white-space: nowrap; "
+        "caption-side: top;}",
+        ".c3table .cell_title {font-weight: bold;}",
+        ".c3col_left { text-align: left !important; display: block;}",
+        ".c3col_right { text-align: right !important; display: block;}",
+        ".c3col_center { text-align: center !important; display: block;}",
+    )
+)
+
 
 def _merged_cell_text_wrap(text, max_line_length, space):
     """ left justify wraps text into multiple rows"""
@@ -155,22 +175,39 @@ def rich_html(
     return data
 
 
-def latex(rows, header=None, caption=None, justify=None, label=None, position=None):
+def latex(
+    rows,
+    header=None,
+    caption=None,
+    legend=None,
+    justify=None,
+    label=None,
+    position=None,
+):
     """Returns the text a LaTeX table.
 
     Parameters
     ----------
+    rows
+        table data in row orientation
     header
         table header
-    position
-        table page position, default is here, top separate page
+    caption
+        title text.
+    legend
+        If provided, the text is placed in a \\caption*{} command at the
+        bottom of the table and the caption is placed at the top.
     justify
         column justification, default is right aligned.
-    caption
-        Table legend
     label
         for cross referencing
+    position
+        table page position, default is here, top separate page
 
+    Notes
+    -----
+    The \\caption*{} command is provided with the caption package. See
+    https://ctan.org/pkg/caption for more details.
     """
 
     if not justify:
@@ -186,18 +223,30 @@ def latex(rows, header=None, caption=None, justify=None, label=None, position=No
         r"\begin{table}[%s]" % position,
         r"\centering",
         r"\begin{tabular}%s" % justify,
+        r"\hline",
+        header,
+        r"\hline",
+        r"\hline",
     ]
-    table_format.append(r"\hline")
-    table_format.append(header)
-    table_format.append(r"\hline")
-    table_format.append(r"\hline")
     table_format += rows
     table_format.append(r"\hline")
     table_format.append(r"\end{tabular}")
-    if caption:
-        table_format.append(r"\caption{%s}" % caption)
-    if label:
-        table_format.append(r"\label{%s}" % label)
+
+    caption = r"\caption{%s}" % caption if caption else ""
+    label = r"\label{%s}" % label if label else ""
+    legend = r"\caption*{%s}" % legend if isinstance(legend, str) else None
+    if caption and label:
+        caption = f"{caption}\n{label}"
+    elif caption or label:
+        caption = caption or label
+
+    if caption and legend:
+        table_format.insert(2, caption)
+    elif caption:
+        table_format.append(caption)
+
+    if legend is not None:
+        table_format.append(legend)
     table_format.append(r"\end{table}")
 
     return "\n".join(table_format)
@@ -218,33 +267,45 @@ def get_continuation_tables(
     if len(space.join(header)) < max_width:
         return [(header, formatted_table)]
 
-    if not identifiers:
-        identifiers = 0
     # having determined the maximum string lengths we now need to
     # produce subtables of width <= max_width
     col_widths = [len(head) for head in header]
     sep = len(space)
-    min_length = sep * (identifiers - 1) + sum(col_widths[:identifiers])
+    min_length = col_widths[0]
 
     if min_length > max_width:
         raise RuntimeError("Maximum width too small for identifiers")
 
-    begin, width = identifiers, min_length
+    # if we have an index column, every new table block includes that width
+    # in calculating the number of columns; otherwise it's simply the sum
+    if identifiers:
+        id_width = col_widths[0] + sep
+        begin = 1
+    else:
+        id_width = 0
+        begin = 0
 
+    width = id_width
     boundaries = []
     for i in range(begin, len(header)):
         width += col_widths[i] + sep
         if width > max_width:
-            boundaries.append((begin, i, width - col_widths[i] - sep))
-            width = min_length + col_widths[i] + sep
+            boundaries.append((begin, i))
             begin = i
+            width = id_width + col_widths[i]
 
-    # add the last sub-table
-    boundaries.append((begin, len(header), width))
-    # generate the table
-    for start, end, width in boundaries:
-        subhead = header[:identifiers] + header[start:end]
-        rows = [row[:identifiers] + row[start:end] for row in formatted_table]
+    boundaries.append((begin, len(header)))
+    data = {c[0].strip(): c[1:] for c in zip(header, *formatted_table)}
+    for start, end in boundaries:
+        if identifiers:
+            subhead = header[:1] + header[start:end]
+        else:
+            subhead = header[start:end]
+        rows = numpy.array([data[c.strip()] for c in subhead], dtype="<U15")
+        if rows.ndim == 1:
+            rows = [rows.tolist()]
+        else:
+            rows = rows.T.tolist()
         tables.append((subhead, rows))
 
     return tables
@@ -277,8 +338,8 @@ def simple_format(
         forces wrapping of table onto successive lines if its'
         width exceeds that specified
     identifiers
-        column index for the last column that uniquely identify
-        rows. Required if table width exceeds max_width.
+        index for the column that uniquely identify rows. Required if table
+        width exceeds max_width.
     borders
         whether to display borders.
     space
@@ -363,7 +424,8 @@ def markdown(header, formatted_table, space=1, justify=None):
         previously formatted to the same width within a column.
     space
         number of spaces surrounding the cell contents, must be >= 1
-
+    justify
+        characters indicating alignment of columns
     """
     assert space >= 1, "space must be >= 1"
     if justify is not None:
@@ -397,6 +459,42 @@ def markdown(header, formatted_table, space=1, justify=None):
     return "\n".join(rows)
 
 
+def rst_csv_table(header, formatted_table, title=None, legend=None):
+    """Returns a table in restructured text csv-table format
+
+    Parameters
+    ----------
+    header
+        series of strings
+    formatted_table
+        formatted strings, row based
+    title, legend
+        combined in this format
+
+    Returns
+    -------
+    str
+
+    Notes
+    -----
+    We only support a subset of available attr, see
+    https://docutils.sourceforge.io/docs/ref/rst/directives.html#csv-table
+    """
+    header = ", ".join(f'"{c}"' for c in header)
+    header = f"    :header: {header}"
+    rows = "\n".join(f"    {', '.join(r)}" for r in formatted_table)
+
+    if title or legend:
+        title = f" {title}" if title else ""
+        title = f"{title} {legend}" if legend else title
+    else:
+        title = ""
+
+    table = [f".. csv-table::{title}", header, "", rows]
+
+    return "\n".join(table)
+
+
 def grid_table_format(header, formatted_table, title=None, legend=None):
     """Returns a table in restructured text grid format.
 
@@ -596,13 +694,12 @@ def formatted_cells(
 
     """
     if not header:
-        num_col = max([len(row) for row in rows])
+        num_col = max(len(row) for row in rows)
         header = [""] * num_col
     else:
         num_col = len(header)
 
     col_widths = [len(col) for col in header]
-    num_row = len(rows)
     column_templates = column_templates or {}
 
     float_template = "{0:.%df}" % digits
@@ -617,7 +714,8 @@ def formatted_cells(
             except IndexError:
                 entry = "%s" % missing_data
             else:
-                if not entry:
+                not_missing = True if isinstance(entry, numpy.ndarray) else entry
+                if not not_missing:
                     try:
                         float(entry)  # could numerically be 0, so not missing
                     except (ValueError, TypeError):
@@ -722,3 +820,252 @@ def phylip_matrix(rows, names):
         dmat += append_species(name, rows[i], mat_breaks)
 
     return "\n".join(dmat)
+
+
+def get_continuation_tables_headers(
+    cols_widths, index_name=None, space=2, max_width=1e100
+):
+    """
+    returns column headers for continuation tables segmented to not exceed max_width
+
+    Parameters
+    ----------
+    cols_widths : list
+        [[col_name, length of longest string], ...]
+    index_name : str
+        column name of an index. This column included in all sub table headers.
+    space : int
+        how much white space between columns
+    max_width : int
+        maximum width
+
+    Returns
+    -------
+    list of lists, each inner list is the column names for a subtable
+    """
+    width_map = dict(cols_widths)
+    index_width = 0 if index_name is None else width_map[index_name]
+    for name, width in width_map.items():
+        if index_width + width > max_width:
+            raise ValueError(
+                f"{index_name}={index_width} + {name} width={width} > max_width={max_width}"
+            )
+
+    if sum(v + space + index_width for _, v in cols_widths) < max_width:
+        return [[l for l, _ in cols_widths]]
+
+    headers = []
+    curr = [index_name] if index_name is not None else []
+    cum_sum = index_width
+    for name, width in cols_widths:
+        if name == index_name:
+            continue
+
+        cum_sum += space + width
+        if cum_sum > max_width:
+            headers.append(curr)
+            curr = [index_name, name] if index_name is not None else [name]
+            cum_sum = index_width + space + width
+            continue
+
+        curr.append(name)
+
+    headers.append(curr)
+
+    return headers
+
+
+class _MixedFormatter:
+    """handles formatting of mixed data types"""
+
+    def __init__(
+        self, alignment, length, precision=4, float_type="f", missing_data=None
+    ):
+        self.missing_data = missing_data
+        self.length = length
+        self.alignment = alignment
+        self.precision = precision
+        self.float_type = float_type
+
+    def __call__(self, val):
+        prefix = f"{self.alignment}{self.length}"
+        float_spec = f"{prefix}.{self.precision}{self.float_type}"
+        int_spec = f"{prefix}d"
+        result = str(val)
+        if self.missing_data is not None and not result:
+            return self.missing_data
+
+        for fspec in (int_spec, float_spec, prefix):
+            try:
+                result = format(val, fspec)
+                break
+            except (TypeError, ValueError):
+                pass
+
+        return result
+
+
+def formatted_array(
+    series,
+    title="",
+    precision=4,
+    format_spec=None,
+    missing_data="",
+    pad=True,
+    align="r",
+):
+    """converts elements in a numpy array series to an equal length string.
+
+    Parameters
+    ----------
+    series
+        the series of table rows
+    title
+        title of series
+    precision
+        number of decimal places. Can be overridden by following.
+    format_spec
+        format specification as per the python Format Specification, Mini-Language
+        or a callable function.
+    missing_data
+        default missing data value.
+    pad : bool
+        Whether to pad all strings to same length. If False, alignment setting is
+        ignored.
+    align : str
+        either 'l', 'c', 'r' for left, center or right alignment, Defaults to 'r'.
+        Only applied if pad==True
+
+    Returns
+    -------
+    list of formatted series, formatted title, maximum string length
+
+    Notes
+    -----
+    The precedence for formatting is format_spec supersedes pad, precision and
+    align values.
+    """
+    assert isinstance(series, numpy.ndarray), "must be numpy array"
+    if pad and align.lower() not in set("lrc"):
+        raise ValueError(f"align value '{align}' not in 'l,c,r'")
+
+    if pad:
+        align = {"l": "<", "c": "^", "r": ">"}[align]
+
+    if callable(format_spec):
+        formatter = format_spec
+        format_spec = None
+    else:
+        formatter = None
+
+    if format_spec and set(format_spec.strip()) <= set("<>^"):
+        # format_spec just an alignment character, in which case we assign
+        # that to align and reset format_spec as None so other formatting
+        # options have an effect
+        align = format_spec
+        format_spec = None
+
+    if isinstance(format_spec, str):
+        format_spec = format_spec.replace("%", "")
+
+    if not any([format_spec, formatter]):
+        type_name = series.dtype.name
+        if "int" in type_name:
+            base_format = "d"
+        elif "float" in type_name:
+            base_format = f".{precision}f"
+        elif "bool" == type_name:
+            base_format = ""
+        else:
+            # handle mixed types with a custom formatter
+            formatter = _MixedFormatter(
+                align, len(title), precision, missing_data=missing_data
+            )
+            base_format = ""
+
+        format_spec = base_format
+
+    formatted = []
+    max_length = len(title)
+    for i, v in enumerate(series):
+        if formatter:
+            v = formatter(v)
+        else:
+            try:
+                v = format(v, format_spec)
+            except (TypeError, ValueError):
+                # could be a python object
+                v = str(v)
+
+        l = len(v)
+        if l > max_length:
+            max_length = l
+
+        formatted.append(v)
+
+    if not pad:
+        return formatted, title.strip(), max_length
+
+    if format_spec:
+        match = re.search("[<>^]", format_spec[:2])
+        final_align = align if match is None else match.group()
+    else:
+        final_align = align
+
+    # now adjust to max_len
+    format_spec = f"{final_align}{max_length}s"
+    title = format(title, format_spec)
+    formatted = [format(v.strip(), format_spec) for v in formatted]
+    return formatted, title, max_length
+
+
+class HtmlElement:
+    """wrapper for text to become a HTML element"""
+
+    def __init__(self, text, tag, css_classes=None, newline=False):
+        """
+        Parameters
+        ----------
+        text : str
+            cell content
+        tag : str
+            html table cell tag, e.g. 'td', 'th'
+        classes : list
+            list of custom CSS classes
+        newline : bool
+            puts the open, close tags on new lines
+        """
+        self.text = str(text)
+        self.tag = tag
+        css_classes = [css_classes] if isinstance(css_classes, str) else css_classes
+        self.css_classes = css_classes
+        self.newline = newline
+
+    def __str__(self):
+        txt = self.text
+        classes = "" if self.css_classes is None else " ".join(self.css_classes)
+        classes = f' class="{classes}"' if classes else ""
+        nl = "\n" if self.newline else ""
+        return f"{nl}<{self.tag}{classes}>{nl}{txt}{nl}</{self.tag}>"
+
+    def __repr__(self):
+        return repr(self.text)
+
+
+def is_html_markup(text):
+    """checks if text contains balanced html markup
+
+    <token ...> body </token>
+    """
+    pattern = re.compile("(?<=[<])[a-z]+")
+    tokens = set(pattern.findall(text))
+    if not tokens:
+        return False
+
+    for token in tokens:
+        num_start = len(re.findall(f"<{token}", text))
+        num_end = len(re.findall(f"</{token}", text))
+        if num_start != num_end:
+            return False
+
+    return True
