@@ -11,7 +11,7 @@ __author__ = "Peter Maxwell"
 __copyright__ = "Copyright 2007-2020, The Cogent Project"
 __credits__ = ["Peter Maxwell", "Gavin Huttley"]
 __license__ = "BSD-3"
-__version__ = "2020.2.7a"
+__version__ = "2020.12.21a"
 __maintainer__ = "Peter Maxwell"
 __email__ = "pm67nz@gmail.com"
 __status__ = "Production"
@@ -76,7 +76,7 @@ class TransitionMatrix(object):
             labels.append(label)
         heading = [""] + labels
         a = [[name] + list(row) for (name, row) in zip(labels, self.Matrix)]
-        return str(Table(header=heading, rows=a))
+        return str(Table(header=heading, data=a))
 
     def withoutSilentStates(self):
         """An equivalent matrix without any of the states that have a
