@@ -4,7 +4,11 @@
 Also provides NumberList and FrequencyDistribution, two classes for
 working with statistical data.
 """
+from .distribution import chi_high as chisqprob
+
+
 __all__ = [
+    "chisqprob",
     "contingency",
     "distribution",
     "information_criteria",
@@ -14,8 +18,6 @@ __all__ = [
     "test",
 ]
 
-from .distribution import chi_high as chisqprob
-
 
 __author__ = ""
 __copyright__ = "Copyright 2007-2020, The Cogent Project"
@@ -27,7 +29,7 @@ __credits__ = [
     "Micah Hamady",
 ]
 __license__ = "BSD-3"
-__version__ = "2020.2.7a"
-__maintainer__ = "Rob Knight"
-__email__ = "rob@spot.colorado.edu"
+__version__ = "2020.12.21a"
+__maintainer__ = "Gavin Huttley"
+__email__ = "Gavin.Huttley@anu.edu.au"
 __status__ = "Production"
