@@ -17,7 +17,7 @@ __author__ = "Hua Ying, Julien Epps and Gavin Huttley"
 __copyright__ = "Copyright 2007-2020, The Cogent Project"
 __credits__ = ["Julien Epps", "Hua Ying", "Gavin Huttley"]
 __license__ = "BSD-3"
-__version__ = "2020.2.7a"
+__version__ = "2020.12.21a"
 __maintainer__ = "Gavin Huttley"
 __email__ = "Gavin.Huttley@anu.edu.au"
 __status__ = "Production"
@@ -65,7 +65,7 @@ def g_statistic(X, p=None, idx=None):
     return g_obs, p_val
 
 
-def _seq_to_symbols(seq, motifs, motif_length, result=None):
+def seq_to_symbols(seq, motifs, motif_length, result=None):
     """return symbolic represetation of the sequence
 
     Parameters
@@ -93,12 +93,6 @@ def _seq_to_symbols(seq, motifs, motif_length, result=None):
     return result
 
 
-try:
-    from cogent3.maths._period import seq_to_symbols
-except ImportError:
-    seq_to_symbols = _seq_to_symbols
-
-
 class SeqToSymbols(object):
     """class for converting all occurrences of motifs in passed sequence
     to 1/0 otherwise"""
