@@ -4,19 +4,15 @@
 
 import warnings
 
-from operator import add
-from random import choice
-
 from numpy import (
     absolute,
+    allclose,
     any,
     arctanh,
     array,
     asarray,
-    clip,
     concatenate,
     corrcoef,
-    cov,
     exp,
     fabs,
     isinf,
@@ -25,9 +21,10 @@ from numpy import (
     mean,
 )
 from numpy import median as _median
-from numpy import nan, nonzero, ones, ravel, reshape, sqrt
+from numpy import nonzero, ones, ravel, sqrt
+from numpy import std as _std
 from numpy import sum as npsum
-from numpy import take, tanh, trace, transpose, zeros
+from numpy import take, tanh, trace, zeros
 from numpy.random import permutation, randint
 
 from cogent3.maths.stats.distribution import (
@@ -55,6 +52,7 @@ from cogent3.maths.stats.special import (
     log_one_minus,
     one_minus_exp,
 )
+from cogent3.util.warning import discontinued
 
 
 __author__ = "Rob Knight"
@@ -71,50 +69,49 @@ __credits__ = [
     "Michael Dwan",
 ]
 __license__ = "BSD-3"
-__version__ = "2020.2.7a"
-__maintainer__ = "Rob Knight"
-__email__ = "rob@spot.colorado.edu"
+__version__ = "2020.12.21a"
+__maintainer__ = "Gavin Huttley"
+__email__ = "Gavin.Huttley@anu.edu.au"
 __status__ = "Production"
 
 
+# defining globals for the alternate hypotheses
+ALT_TWO_SIDED = "2"
+ALT_LOW = "low"
+ALT_HIGH = "high"
+
+
+def _get_alternate(value: str):
+    """identify the alternate hypothesis
+
+    Parameters
+    ----------
+    value : str
+        the input alternate
+
+    Returns
+    -------
+    the corresponding global ALT_LOW, ALT_HIGH, ALT_TWO_SIDED
+    """
+    value = value.lower()
+    alts = {k: ALT_LOW for k in ("less", "lo", "low", "lower", "l", "lt", "<")}
+    alts.update({k: ALT_HIGH for k in ("greater", "hi", "high", "h", "g", "gt", ">")})
+    alts.update(
+        {
+            k: ALT_TWO_SIDED
+            for k in ("two sided", "2", "two tailed", "two", "two.sided", "ts")
+        }
+    )
+    alt = alts.get(value, None)
+    if alt is None:
+        raise ValueError(f"alternate hypothesis '{value}' not in {sorted(alts)}")
+    return alt
+
+
 class IndexOrValueError(IndexError, ValueError):
     pass
 
 
-var = cov  # cov will calculate variance if called on a vector
-
-
-def std_(x, axis=None):
-    """Returns standard deviations by axis (similiar to numpy.std)
-
-    The result is unbiased, matching the result from MLab.std
-    """
-    x = asarray(x)
-
-    if axis is None:
-        d = x - mean(x)
-        return sqrt(npsum(d ** 2) / (len(x) - 1))
-    elif axis == 0:
-        result = []
-        for col in range(x.shape[1]):
-            vals = x[:, col]
-            d = vals - mean(vals)
-            result.append(sqrt(npsum(d ** 2) / (len(x) - 1)))
-        return result
-    elif axis == 1:
-        result = []
-        for row in range(x.shape[0]):
-            vals = x[row, :]
-            d = vals - mean(vals)
-            result.append(sqrt(npsum(d ** 2) / (len(x) - 1)))
-        return result
-    else:
-        raise ValueError("axis out of bounds")
-
-
-# tested only by std
-
-
 def var(x, axis=None):
     """Returns unbiased standard deviations over given axis.
 
@@ -140,7 +137,7 @@ def var(x, axis=None):
     return sample_SS / (n - 1)
 
 
-def std(x, axis=None):
+def std(x, axis=None):  # pragma: no cover
     """computed unbiased standard deviations along given axis or flat array.
 
     Similar with numpy.std, except that it is unbiased. (var = SS/n-1)
@@ -156,12 +153,13 @@ def std(x, axis=None):
     return sqrt(sample_variance)
 
 
-def median(m, axis=None):
+def median(m, axis=None):  # pragma: no cover
     """Returns medians by axis (similiar to numpy.mean)
 
     numpy.median does not except an axis parameter. Is safe for substition for
     numpy.median
     """
+    discontinued("function", "median", "2021.11")
     median_vals = []
     rows, cols = m.shape
 
@@ -439,20 +437,27 @@ def bayes_updates(ds_given_h, priors=None):
 def t_paired(a, b, tails=None, exp_diff=0):
     """Returns t and prob for TWO RELATED samples of scores a and b.
 
-    From Sokal and Rohlf (1995), p. 354.
-    Calculates the vector of differences and compares it to exp_diff
-    using the 1-sample t test.
+    Parameters
+    ----------
+    a, b
+        equal length lists of paired observations (numbers).
+    tails
+        tails should be None (default), 'high', or 'low'.
+    exp_diff
+        The expected difference in means (a-b); 0 by default.
 
-    Usage:   t, prob = t_paired(a, b, tails, exp_diff)
+    Returns
+    -------
+    t, prob
 
-    t is a float; prob is a probability.
-    a and b should be equal-length lists of paired observations (numbers).
-    tails should be None (default), 'high', or 'low'.
-    exp_diff should be the expected difference in means (a-b); 0 by default.
+    Notes
+    -----
+    From Sokal and Rohlf (1995), p. 354. Calculates the vector of differences
+    and compares it to exp_diff using the 1-sample t test.
     """
     n = len(a)
     if n != len(b):
-        raise ValueError("Unequal length lists in ttest_paired.")
+        raise ValueError("Unequal length lists in t_paired.")
     try:
         diffs = array(a) - array(b)
         return t_one_sample(diffs, popmean=exp_diff, tails=tails)
@@ -474,11 +479,10 @@ def t_one_sample(a, popmean=0, tails=None):
     t is a float; prob is a probability.
     a should support Mean, StandardDeviation, and Count.
     popmean should be the expected mean; 0 by default.
-    tails should be None (default), 'high', or 'low'.
-"""
+    tails should be None (default), 'high', or 'low'."""
     try:
         n = len(a)
-        t = (mean(a) - popmean) / (std(a) / sqrt(n))
+        t = (mean(a) - popmean) / (_std(a, ddof=1) / sqrt(n))
     except (
         ZeroDivisionError,
         ValueError,
@@ -497,18 +501,18 @@ def t_one_sample(a, popmean=0, tails=None):
 def t_two_sample(a, b, tails=None, exp_diff=0, none_on_zero_variance=True):
     """Returns t, prob for two INDEPENDENT samples of scores a, and b.
 
-    From Sokal and Rohlf, p 223.
-
-    Usage:   t, prob = t_two_sample(a,b, tails, exp_diff)
-
-    t is a float; prob is a probability.
-    a and b should be sequences of observations (numbers). Need not be equal
-        lengths.
-    tails should be None (default), 'high', or 'low'.
-    exp_diff should be the expected difference in means (a-b); 0 by default.
-    none_on_zero_variance: if True, will return (None,None) if both a and b
-        have zero variance (e.g. a=[1,1,1] and b=[2,2,2]). If False, the
-        following values will be returned:
+    Parameters
+    ----------
+    a, b
+        equal length lists of paired observations (numbers).
+    tails
+        tails should be None (default), 'high', or 'low'.
+    exp_diff
+        The expected difference in means (a-b); 0 by default.
+    none_on_zero_variance
+        if True, will return (None,None) if both a and b have zero variance
+        (e.g. a=[1,1,1] and b=[2,2,2]). If False, the following values will
+        be returned:
 
             Two-tailed test (tails=None):
                 a < b: (-inf,0.0)
@@ -524,11 +528,17 @@ def t_two_sample(a, b, tails=None, exp_diff=0, none_on_zero_variance=True):
 
         If a and b both have no variance and have the same single value (e.g.
         a=[1,1,1] and b=[1,1,1]), (None,None) will always be returned.
+
+    Returns
+    -------
+    t, prob
+
+    Notes
+    -----
+    From Sokal and Rohlf, p 223.
     """
-    if tails is not None and tails != "high" and tails != "low":
-        raise ValueError(
-            "Invalid tail type '%s'. Must be either None, " "'high', or 'low'." % tails
-        )
+    tails = tails or "2"
+    tails = _get_alternate(str(tails))
 
     try:
         # see if we need to back off to the single-observation for single-item
@@ -604,17 +614,15 @@ def t_two_sample(a, b, tails=None, exp_diff=0, none_on_zero_variance=True):
 
 def _t_test_no_variance(mean1, mean2, tails):
     """Handles case where two distributions have no variance."""
-    if tails is not None and tails != "high" and tails != "low":
-        raise ValueError(
-            "Invalid tail type '%s'. Must be either None, " "'high', or 'low'." % tails
-        )
+    tails = tails or "2"
+    tails = _get_alternate(str(tails))
 
-    if tails is None:
+    if tails == ALT_TWO_SIDED:
         if mean1 < mean2:
             result = (float("-inf"), 0.0)
         else:
             result = (float("inf"), 0.0)
-    elif tails == "high":
+    elif tails == ALT_HIGH:
         if mean1 < mean2:
             result = (float("-inf"), 1.0)
         else:
@@ -655,10 +663,8 @@ def mc_t_two_sample(x_items, y_items, tails=None, permutations=999, exp_diff=0):
         exp_diff - the expected difference in means (x_items - y_items)
 
     """
-    if tails is not None and tails != "high" and tails != "low":
-        raise ValueError(
-            "Invalid tail type '%s'. Must be either None, " "'high', or 'low'." % tails
-        )
+    tails = tails or "2"
+    tails = _get_alternate(str(tails))
     if permutations < 0:
         raise ValueError(
             "Invalid number of permutations: %d. Must be greater "
@@ -701,11 +707,11 @@ def mc_t_two_sample(x_items, y_items, tails=None, permutations=999, exp_diff=0):
         ]
 
         # Compute nonparametric p-value based on the permuted t-test results.
-        if tails is None:
+        if tails == ALT_TWO_SIDED:
             better = (absolute(array(perm_t_stats)) >= absolute(obs_t)).sum()
-        elif tails == "low":
+        elif tails == ALT_LOW:
             better = (array(perm_t_stats) <= obs_t).sum()
-        elif tails == "high":
+        elif tails == ALT_HIGH:
             better = (array(perm_t_stats) >= obs_t).sum()
         nonparam_p_val = (better + 1) / (permutations + 1)
 
@@ -748,7 +754,7 @@ def t_one_observation(x, sample, tails=None, exp_diff=0, none_on_zero_variance=T
     """
     try:
         sample_mean = mean(sample)
-        sample_std = std(sample)
+        sample_std = _std(sample, ddof=1)
 
         if sample_std == 0:
             # The list does not vary.
@@ -820,6 +826,8 @@ def pearson(x_items, y_items):
         )
     except (ZeroDivisionError, ValueError, FloatingPointError):  # no variation
         r = 0.0
+
+    r = 0.0 if isnan(r) else r
     # check we didn't get a naughty value for r due to rounding error
     if r > 1.0:
         r = 1.0
@@ -831,16 +839,19 @@ def pearson(x_items, y_items):
 def spearman(x_items, y_items):
     """Returns Spearman's rho.
 
+    Parameters
+    ----------
+    x_items
+        the first list of observations
+    y_items
+        the second list of observations
+
+    Notes
+    -----
     This will always be a value between -1.0 and +1.0. x_items and y_items must
     be the same length, and cannot have fewer than 2 elements each. If one or
     both of the input vectors do not have any variation, the return value will
     be 0.0.
-
-    Parameters
-    ----------
-        x_items - the first list of observations
-        y_items - the second list of observations
-
     """
     x_items, y_items = array(x_items), array(y_items)
 
@@ -912,6 +923,49 @@ def _get_rank(data):
     return ranks, ties
 
 
+def pearson_correlation(x, y, tails=None):
+    """Computes the Pearson correlation between two vectors and its significance.
+
+    Parameters
+    ----------
+    x
+        the first list of observations
+    y
+        the second list of observations
+    tails
+        if None (the default), a two-sided test is performed. 'high' for a
+        one-tailed test for positive association, or 'low' for a one-tailed
+        test for negative association.
+
+    Returns
+    -------
+    Rho, pvalue
+
+    Notes
+    -----
+    Computes a parametric p-value by using Student's t-distribution with df=n-2
+    to perform the test of significance.
+    """
+    assert len(x) == len(y), f"unequal lengths of x ({len(x)}) and y ({len(y)})"
+    n = len(x)
+    tails = tails or "2"
+    tails = _get_alternate(str(tails))
+
+    # Calculate the correlation coefficient.
+    rho = pearson(x, y)
+    if allclose(rho, 1.0):
+        return rho, 0
+
+    df = n - 2
+    if n < 3:
+        pvalue = 1
+    else:
+        t = rho / sqrt((1 - (rho * rho)) / df)
+        pvalue = t_tailed_prob(t, df, tails)
+
+    return rho, pvalue
+
+
 def correlation(x_items, y_items):
     """Returns Pearson correlation between x and y, and its significance.
 
@@ -935,6 +989,33 @@ def correlation_test(
 ):
     """Computes the correlation between two vectors and its significance.
 
+    Parameters
+    ----------
+    x_items
+        the first list of observations
+    y_items
+        the second list of observations
+    method : str
+        'pearson' or 'spearman'
+    tails
+        if None (the default), a two-sided test is performed. 'high' for a
+        one-tailed test for positive association, or 'low' for a one-tailed
+        test for negative association. This parameter affects both the
+        parametric and nonparametric tests, but the confidence interval
+        will always be two-sided permutations - the number of permutations
+        to use in the nonparametric test. Must be a number greater than or
+        equal to 0. If 0, the nonparametric test will not be performed. In
+        this case, the list of correlation coefficients obtained from
+        permutations will be empty, and the nonparametric p-value will be None
+    permutations : int
+        Permutes one of the input vectors theis number of times. Used in the
+        nonparametric test.
+    confidence_level
+        the confidence level to use when constructing the
+        confidence interval. Must be between 0 and 1 (exclusive)
+
+    Notes
+    -----
     Computes a parametric p-value by using Student's t-distribution with df=n-2
     to perform the test of significance, as well as a nonparametric p-value
     obtained by permuting one of the input vectors the specified number of
@@ -943,9 +1024,6 @@ def correlation_test(
     greater than 3. Please see Sokal and Rohlf pp. 575-580 and pg. 598-601 for
     more details regarding these techniques.
 
-    Warning: the parametric p-value is unreliable when the method is spearman
-    and there are less than 11 observations in each vector.
-
     Returns the correlation coefficient (r or rho), the parametric p-value, a
     list of the r or rho values obtained from permuting the input, the
     nonparametric p-value, and a tuple for the confidence interval, with the
@@ -958,27 +1036,13 @@ def correlation_test(
     elements each. If one or both of the input vectors do not have any
     variation, r or rho will be 0.0.
 
-    Note: the parametric portion of this function is based on the correlation
+    The parametric portion of this function is based on the correlation
     function in this module.
 
-    Parameters
-    ----------
-        x_items - the first list of observations
-        y_items - the second list of observations
-        method - 'pearson' or 'spearman'
-        tails - if None (the default), a two-sided test is performed. 'high'
-        for a one-tailed test for positive association, or 'low' for a
-        one-tailed test for negative association. This parameter affects
-        both the parametric and nonparametric tests, but the confidence
-        interval will always be two-sided
-        permutations - the number of permutations to use in the nonparametric
-        test. Must be a number greater than or equal to 0. If 0, the
-        nonparametric test will not be performed. In this case, the list of
-        correlation coefficients obtained from permutations will be empty,
-        and the nonparametric p-value will be None
-        confidence_level - the confidence level to use when constructing the
-        confidence interval. Must be between 0 and 1 (exclusive)
-
+    Warning
+    -------
+    The parametric p-value is unreliable when the method is spearman
+    and there are less than 11 observations in each vector.
     """
     # Perform some initial error checking.
     if method == "pearson":
@@ -1074,14 +1138,8 @@ def correlation_test(
 
 
 def correlation_matrix(series, as_rows=True):
-    """Returns pairwise correlations between each pair of series.
-    """
+    """Returns pairwise correlations between each pair of series."""
     return corrcoef(series, rowvar=as_rows)
-    # unused codes below
-    if as_rows:
-        return corrcoef(transpose(array(series)))
-    else:
-        return corrcoef(array(series))
 
 
 def regress(x, y):
@@ -1167,7 +1225,7 @@ def regress_residuals(x, y):
 def stdev_from_mean(x):
     """returns num standard deviations from the mean of each val in x[]"""
     x = array(x)
-    return (x - mean(x)) / std(x)
+    return (x - x.mean()) / x.std(ddof=1)
 
 
 def regress_major(x, y):
@@ -1197,17 +1255,26 @@ def regress_major(x, y):
 def z_test(a, popmean=0, popstdev=1, tails=None):
     """Returns z and probability score for a single sample of items.
 
-Calculates the z-score on ONE sample of items with mean x, given a population
-mean and standard deviation (parametric).
+    Parameters
+    ----------
+    a
+        list of observations (numbers).
+    popmean
+        the parametric population mean; 0 by default
+    popstdev
+        the parametric population standard deviation, 1 by default.
+    tails
+        tails should be None (default), 'high', or 'low'.
 
-Usage:   z, prob = z_test(a, popmean, popstdev, tails)
+    Returns
+    -------
+    z, prob
 
-z is a float; prob is a probability.
-a is a sample with Mean and Count.
-popmean should be the parametric population mean; 0 by default.
-popstdev should be the parametric population standard deviation, 1 by default.
-tails should be None (default), 'high', or 'low'.
-"""
+    Notes
+    -----
+    Calculates the z-score on ONE sample of items with mean x, given a
+    population mean and standard deviation (parametric).
+    """
     try:
         z = (mean(a) - popmean) / popstdev * sqrt(len(a))
         return z, z_tailed_prob(z, tails)
@@ -1233,9 +1300,12 @@ def z_tailed_prob(z, tails):
 
 def t_tailed_prob(t, df, tails):
     """Return appropriate p-value for given t and df, depending on tails."""
-    if tails == "high":
+    tails = tails or "2"
+    tails = _get_alternate(str(tails))
+
+    if tails == ALT_HIGH:
         return t_high(t, df)
-    elif tails == "low":
+    elif tails == ALT_LOW:
         return t_low(t, df)
     else:
         return tprob(t, df)
@@ -1243,17 +1313,19 @@ def t_tailed_prob(t, df, tails):
 
 def reverse_tails(tails):
     """Swaps high for low or vice versa, leaving other values alone."""
-    if tails == "high":
-        return "low"
-    elif tails == "low":
-        return "high"
+    tails = tails or "2"
+    tails = _get_alternate(str(tails))
+
+    if tails == ALT_HIGH:
+        return ALT_LOW
+    elif tails == ALT_LOW:
+        return ALT_HIGH
     else:
         return tails
 
 
 def tail(prob, test):
-    """If test is true, returns prob/2. Otherwise returns 1-(prob/2).
-    """
+    """If test is true, returns prob/2. Otherwise returns 1-(prob/2)."""
     prob /= 2
     if test:
         return prob
@@ -1263,8 +1335,7 @@ def tail(prob, test):
 
 # todo delete, now from itertools.combinations
 def combinations(n, k):
-    """Returns the number of ways of choosing k items from n.
-    """
+    """Returns the number of ways of choosing k items from n."""
     return exp(lgam(n + 1) - lgam(k + 1) - lgam(n - k + 1))
 
 
@@ -1338,10 +1409,13 @@ def f_two_sample(a, b, tails=None):
 
     This implementation returns the same results as the F test in R.
     """
+    tails = tails or "2"
+    tails = _get_alternate(str(tails))
+
     dfn, dfd, F = f_value(a, b)
-    if tails == "low":
+    if tails == ALT_LOW:
         return dfn, dfd, F, f_low(dfn, dfd, F)
-    elif tails == "high":
+    elif tails == ALT_HIGH:
         return dfn, dfd, F, f_high(dfn, dfd, F)
     else:
         if var(a) >= var(b):
@@ -1398,16 +1472,19 @@ def MonteCarloP(value, rand_values, tail="high"):
         low = look for smaller values than expected by chance
         high = look for larger values than expected by chance
     """
+    tail = tail or "2"
+    tail = _get_alternate(str(tail))
+
     pop_size = len(rand_values)
     rand_values.sort()
-    if tail == "high":
+    if tail == ALT_HIGH:
         num_better = pop_size
         for i, curr_val in enumerate(rand_values):
             if value <= curr_val:
                 num_better = i
                 break
         p_val = 1 - (num_better / pop_size)
-    elif tail == "low":
+    elif tail == ALT_LOW:
         num_better = pop_size
         for i, curr_val in enumerate(rand_values):
             if value < curr_val:
@@ -1422,31 +1499,26 @@ def sign_test(success, trials, alt="two sided"):
 
     Parameters
     ----------
-    success
+    success : int
         the number of successes
-    trials
+    trials : int
         the number of trials
     alt
         the alternate hypothesis, one of 'less', 'greater', 'two sided'
         (default).
-
     """
-    lo = ["less", "lo", "lower", "l"]
-    hi = ["greater", "hi", "high", "h", "g"]
-    two = ["two sided", "2", 2, "two tailed", "two"]
-    alt = alt.lower().strip()
-    if alt in lo:
+    alt = _get_alternate(str(alt))
+    if alt == ALT_LOW:
         p = binomial_low(success, trials, 0.5)
-    elif alt in hi:
+    elif alt == ALT_HIGH:
         success -= 1
         p = binomial_high(success, trials, 0.5)
-    elif alt in two:
+    else:
         success = min(success, trials - success)
         hi = 1 - binomial_high(success, trials, 0.5)
         lo = binomial_low(success, trials, 0.5)
         p = hi + lo
-    else:
-        raise RuntimeError("alternate [%s] not in %s" % (lo + hi + two))
+
     return p
 
 
@@ -1465,29 +1537,24 @@ def ks_test(x, y=None, alt="two sided", exact=None, warn_for_ties=True):
         warns when values are tied. This should left at True
         unless a monte carlo variant, like ks_boot, is being used.
 
-    Note the 1-sample cases are not implemented, although their cdf's are
-    implemented in ks.py"""
-    # translation from R 2.4
+    Notes
+    -----
+    Translated from R 2.4. The 1-sample cases are not implemented, although
+    their cdf's are implemented in ks.py
+    """
+    alt = _get_alternate(str(alt))
+
     num_x = len(x)
-    num_y = None
     x = list(zip(x, zeros(len(x), int)))
-    lo = ["less", "lo", "low", "lower", "l", "lt"]
-    hi = ["greater", "hi", "high", "h", "g", "gt"]
-    two = ["two sided", "2", 2, "two tailed", "two", "two.sided"]
     Pval = None
     if y is not None:  # in anticipation of actually implementing the 1-sample cases
         num_y = len(y)
         y = list(zip(y, ones(len(y), int)))
         n = num_x * num_y / (num_x + num_y)
         combined = x + y
-        if len(set(combined)) < num_x + num_y:
-            ties = True
-        else:
-            ties = False
-
+        ties = len(set(combined)) < num_x + num_y
         combined = array(combined, dtype=[("stat", float), ("sample", int)])
         combined.sort(order="stat")
-        cumsum = zeros(combined.shape[0], float)
         scales = array([1 / num_x, -1 / num_y])
         indices = combined["sample"]
         cumsum = scales.take(indices)
@@ -1495,25 +1562,25 @@ def ks_test(x, y=None, alt="two sided", exact=None, warn_for_ties=True):
         if exact is None:
             exact = num_x * num_y < 1e4
 
-        if alt in two:
+        if alt == ALT_TWO_SIDED:
             stat = max(fabs(cumsum))
-        elif alt in lo:
+        elif alt == ALT_LOW:
             stat = -cumsum.min()
-        elif alt in hi:
+        elif alt == ALT_HIGH:
             stat = cumsum.max()
         else:
             raise RuntimeError("Unknown alt: %s" % alt)
-        if exact and alt in two and not ties:
+        if exact and alt == ALT_TWO_SIDED and not ties:
             Pval = 1 - psmirnov2x(stat, num_x, num_y)
     else:
         raise NotImplementedError
 
     if Pval is None:
-        if alt in two:
-            Pval = 1 - pkstwo(sqrt(n) * stat)
-        else:
-            Pval = exp(-2 * n * stat ** 2)
-
+        Pval = (
+            1 - pkstwo(sqrt(n) * stat)
+            if alt == ALT_TWO_SIDED and not ties
+            else exp(-2 * n * stat ** 2)
+        )
     if ties and warn_for_ties:
         warnings.warn("Cannot compute correct KS probability with ties")
 
@@ -1529,7 +1596,7 @@ def _get_bootstrap_sample(x, y, num_reps):
     combined = array(list(x) + list(y))
     total_obs = len(combined)
     num_x = len(x)
-    for i in range(num_reps):
+    for _ in range(num_reps):
         # sampling with replacement
         indices = randint(0, total_obs, total_obs)
         sampled = combined.take(indices)
@@ -1550,18 +1617,17 @@ def ks_boot(x, y, alt="two sided", num_reps=1000):
     alt
         alternate hypothesis, as per ks_test
     num_reps
-        number of replicates for the  bootstrap
+        number of replicates for the bootstrap
 
+    Notes
+    -----
+    Based on the ks_boot method in the R Matching package, see
+    http://sekhon.berkeley.edu/matching/
+    One important difference is I preserve the original sample sizes
+    instead of making them equal.
     """
-    # based on the ks_boot method in the R Matching package
-    # see http://sekhon.berkeley.edu/matching/
-    # One important difference is I preserve the original sample sizes
-    # instead of making them equal
     tol = MACHEP * 100
-    combined = array(list(x) + list(y))
     observed_stat, _p = ks_test(x, y, exact=False, warn_for_ties=False)
-    total_obs = len(combined)
-    num_x = len(x)
     num_greater = 0
     for sampled_x, sampled_y in _get_bootstrap_sample(x, y, num_reps):
         sample_stat, _p = ks_test(
@@ -1573,8 +1639,7 @@ def ks_boot(x, y, alt="two sided", num_reps=1000):
 
 
 def _average_rank(start_rank, end_rank):
-    ave_rank = npsum(range(start_rank, end_rank + 1)) / (1 + end_rank - start_rank)
-    return ave_rank
+    return npsum(range(start_rank, end_rank + 1)) / (1 + end_rank - start_rank)
 
 
 def mw_test(x, y):
@@ -1647,13 +1712,12 @@ def mw_boot(x, y, num_reps=1000):
     num_reps
         number of replicates for the  bootstrap
 
+    Notes
+    -----
     Uses the same Monte-Carlo resampling code as kw_boot
     """
     tol = MACHEP * 100
-    combined = array(list(x) + list(y))
     observed_stat, obs_p = mw_test(x, y)
-    total_obs = len(combined)
-    num_x = len(x)
     num_greater = 0
     for sampled_x, sampled_y in _get_bootstrap_sample(x, y, num_reps):
         sample_stat, sample_p = mw_test(sampled_x, sampled_y)
@@ -1665,10 +1729,6 @@ def mw_boot(x, y, num_reps=1000):
 def permute_2d(m, p):
     """Performs 2D permutation of matrix m according to p."""
     return m[p][:, p]
-    # unused below
-    m_t = transpose(m)
-    r_t = take(m_t, p, axis=0)
-    return take(transpose(r_t), p, axis=0)
 
 
 def mantel(m1, m2, n):
@@ -1694,34 +1754,36 @@ def mantel_test(
     Returns the p-value, Mantel correlation statistic, and a list of Mantel
     correlation statistics for each permutation test.
 
-    WARNING: The two distance matrices must be symmetric, hollow distance
-    matrices, as only the lower triangle (excluding the diagonal) will be used
-    in the calculations (matching R's vegan::mantel function).
-
     Parameters
     ----------
-        m1  - the first distance matrix to use in the test (should be a numpy
+    m1
+        the first distance matrix to use in the test (should be a numpy
         array or convertible to a numpy array)
-        m2  - the second distance matrix to use in the test (should be a numpy
+    m2
+        the second distance matrix to use in the test (should be a numpy
         array or convertible to a numpy array)
-        n   - the number of permutations to test when calculating the p-value
-        alt - the type of alternative hypothesis to test (can be either
+    n
+        the number of permutations to test when calculating the p-value
+    alt
+        the type of alternative hypothesis to test (can be either
         'two sided' for a two-sided test, 'greater' or 'less' for one-sided
         tests)
-        suppress_symmetry_and_hollowness_check - by default, the input distance
+    suppress_symmetry_and_hollowness_check
+        by default, the input distance
         matrices will be checked for symmetry and hollowness. It is
         recommended to leave this check in place for safety, as the check
         is fairly fast. However, if you *know* you have symmetric and
         hollow distance matrices, you can disable this check for small
         performance gains on extremely large distance matrices
 
+    Warnings
+    --------
+    The two distance matrices must be symmetric, hollow distance
+    matrices, as only the lower triangle (excluding the diagonal) will be used
+    in the calculations (matching R's vegan::mantel function).
     """
     # Perform some sanity checks on our input.
-    if alt not in ("two sided", "greater", "less"):
-        raise ValueError(
-            "Unrecognized alternative hypothesis. Must be either "
-            "'two sided', 'greater', or 'less'."
-        )
+    alt = _get_alternate(str(alt))
     m1, m2 = asarray(m1), asarray(m2)
     if m1.shape != m2.shape:
         raise ValueError("Both distance matrices must be the same size.")
@@ -1729,9 +1791,10 @@ def mantel_test(
         raise ValueError(
             "The number of permutations must be greater than or " "equal to one."
         )
-    if not suppress_symmetry_and_hollowness_check:
-        if not (is_symmetric_and_hollow(m1) and is_symmetric_and_hollow(m2)):
-            raise ValueError("Both distance matrices must be symmetric and " "hollow.")
+    if not suppress_symmetry_and_hollowness_check and not (
+        is_symmetric_and_hollow(m1) and is_symmetric_and_hollow(m2)
+    ):
+        raise ValueError("Both distance matrices must be symmetric and " "hollow.")
 
     # Get a flattened list of lower-triangular matrix elements (excluding the
     # diagonal) in column-major order. Use these values to calculate the
@@ -1743,17 +1806,17 @@ def mantel_test(
     size = len(m1)
     better = 0
     perm_stats = []
-    for i in range(n):
+    for _ in range(n):
         perm = permute_2d(m1, permutation(size))
         perm_flat = _flatten_lower_triangle(perm)
         r = pearson(perm_flat, m2_flat)
 
-        if alt == "two sided":
+        if alt == ALT_TWO_SIDED:
             if abs(r) >= abs(orig_stat):
                 better += 1
         else:
-            if (alt == "greater" and r >= orig_stat) or (
-                alt == "less" and r <= orig_stat
+            if (alt == ALT_HIGH and r >= orig_stat) or (
+                alt == ALT_LOW and r <= orig_stat
             ):
                 better += 1
         perm_stats.append(r)
@@ -1786,11 +1849,7 @@ def _flatten_lower_triangle(matrix):
 
 def kendall_correlation(x, y, alt="two sided", exact=None, warn=True):
     """returns the statistic (tau) and probability from Kendall's non-parametric
-    test of association that tau==0. Uses the large sample approximation when
-    len(x) >= 50 or when there are ties, otherwise it computes the probability
-    exactly.
-
-    Based on the algorithm implemented in R v2.5
+    test of association that tau==0.
 
     Parameters
     ----------
@@ -1802,17 +1861,19 @@ def kendall_correlation(x, y, alt="two sided", exact=None, warn=True):
     warn
         whether to warn about tied values
 
+    Notes
+    -----
+    Uses the large sample approximation when len(x) >= 50 or when there are
+    ties, otherwise it computes the probability exactly.
+
+    Based on the algorithm implemented in R v2.5
     """
 
     assert len(x) == len(y), "data (x, y) not of same length"
     assert len(x) > 2, "not enough observations"
 
-    # possible alternate hypotheses arguments
-    lo = ["less", "lo", "lower", "l", "lt"]
-    hi = ["greater", "hi", "high", "h", "g", "gt"]
-    two = ["two sided", "2", 2, "two tailed", "two", "two.sided", "ts"]
+    alt = _get_alternate(str(alt))
 
-    ties = False
     num = len(x)
     ties = len(set(x)) != num or len(set(y)) != num
     if ties and warn:
@@ -1823,28 +1884,25 @@ def kendall_correlation(x, y, alt="two sided", exact=None, warn=True):
 
     if num < 50 and not ties and exact:
         combs = int(num * (num - 1) / 2)
-        working = []
-        for i in range(combs):
-            row = [-1 for j in range(combs)]
-            working.append(row)
+        working = -ones((combs, combs), dtype=float)
 
         tau = kendalls_tau(x, y, False)
         q = round((tau + 1) * num * (num - 1) / 4)
-        if alt in two:
+        if alt == ALT_TWO_SIDED:
             if q > num * (num - 1) / 4:
                 p = 1 - pkendall(q - 1, num, Gamma(num + 1), working)
             else:
                 p = pkendall(q, num, Gamma(num + 1), working)
             p = min(2 * p, 1)
-        elif alt in hi:
+        elif alt == ALT_HIGH:
             p = 1 - pkendall(q - 1, num, Gamma(num + 1), working)
-        elif alt in lo:
+        elif alt == ALT_LOW:
             p = pkendall(q, num, Gamma(num + 1), working)
     else:
         tau, p = kendalls_tau(x, y, True)
-        if alt in hi:
+        if alt == ALT_HIGH:
             p /= 2
-        elif alt in lo:
+        elif alt == ALT_LOW:
             p = 1 - p / 2
     return tau, p
 
@@ -1878,6 +1936,8 @@ def distance_matrix_permutation_test(
         one half otherwise the degrees of freedom value will be incorrect.
     """
     # if matrix is symmetric convert all indices to lower trangular
+    tails = tails or "2"
+    tails = _get_alternate(str(tails))
     if is_symmetric:
         cells = get_ltm_cells(cells)
         if cells2:
@@ -1892,7 +1952,7 @@ def distance_matrix_permutation_test(
     count_more_extreme = 0
     stats = []
     indices = list(range(len(matrix)))
-    for k in range(n):
+    for _ in range(n):
         # shuffle the order of indices, and use those to permute the matrix
         permuted_matrix = permute_2d(matrix, permutation(indices))
         special_values, other_values = get_values_from_matrix(
@@ -1902,13 +1962,13 @@ def distance_matrix_permutation_test(
         # with these p-values, we only use the current_stat value)
         current_stat, current_p = f(special_values, other_values, tails)
         stats.append(current_stat)
-        if tails is None:
+        if tails == ALT_TWO_SIDED:
             if abs(current_stat) > abs(stat):
                 count_more_extreme += 1
-        elif tails == "low":
+        elif tails == ALT_LOW:
             if current_stat < stat:
                 count_more_extreme += 1
-        elif tails == "high":
+        elif tails == ALT_HIGH:
             if current_stat > stat:
                 count_more_extreme += 1
 
@@ -1924,11 +1984,11 @@ def distance_matrix_permutation_test(
 def get_values_from_matrix(matrix, cells, cells2=None, is_symmetric=True):
     """get values from matrix positions in cells and cells2
 
-        matrix: the numpy array from which values should be taken
-        cells: indices of first set of requested values
-        cells2: indices of second set of requested values or None
-         if they should be randomly selected
-        is_symmetric: True if matrix is symmetric
+    matrix: the numpy array from which values should be taken
+    cells: indices of first set of requested values
+    cells2: indices of second set of requested values or None
+     if they should be randomly selected
+    is_symmetric: True if matrix is symmetric
 
     """
 
@@ -1955,8 +2015,8 @@ def get_values_from_matrix(matrix, cells, cells2=None, is_symmetric=True):
 def get_ltm_cells(cells):
     """converts matrix indices so all are below the diagonal
 
-        cells: list of indices into a 2D integer-indexable object
-         (typically a list or lists of array of arrays)
+    cells: list of indices into a 2D integer-indexable object
+     (typically a list or lists of array of arrays)
 
     """
     new_cells = []
