@@ -88,7 +88,7 @@ __author__ = "Peter Maxwell"
 __copyright__ = "Copyright 2007-2020, The Cogent Project"
 __credits__ = ["Peter Maxwell", "Gavin Huttley"]
 __license__ = "BSD-3"
-__version__ = "2020.2.7a"
+__version__ = "2020.12.21a"
 __maintainer__ = "Peter Maxwell"
 __email__ = "pm67nz@gmail.com"
 __status__ = "Production"
@@ -287,11 +287,7 @@ class _InputDefn(_LeafDefn):
             k: set(v) for k, v in zip(range(num_valid_dims), zip(*self.index))
         }
 
-        discard = []
-        for k, v in dimensioned.items():
-            if len(v) == 1:
-                discard.append(k)
-
+        discard = [k for k, v in dimensioned.items() if len(v) == 1]
         for k in discard:
             del dimensioned[k]
 
