@@ -15,7 +15,7 @@ __author__ = "Gavin Huttley"
 __copyright__ = "Copyright 2007-2020, The Cogent Project"
 __credits__ = ["Gavin Huttley", "Stephen Ma"]
 __license__ = "BSD-3"
-__version__ = "2020.2.7a"
+__version__ = "2020.12.21a"
 __maintainer__ = "Gavin Huttley"
 __email__ = "Gavin.Huttley@anu.edu.au"
 __status__ = "Alpha"
@@ -142,11 +142,11 @@ class FastSlowDistTests(TestCase):
         fast_slow_dist = dist_app.fast_slow_dist(slow_calc="GTR")
         got = fast_slow_dist(aln3).to_dict()
         assert_allclose(got[("Human", "Mouse")], got[("Mouse", "Human")])
-        self.assertTrue(0 <= got[("Mouse", "Human")])
+        self.assertTrue(got[("Mouse", "Human")] >= 0)
         fast_slow_dist = dist_app.fast_slow_dist(slow_calc="TN93")
         got = fast_slow_dist(aln3).to_dict()
         assert_allclose(got[("Human", "Mouse")], got[("Mouse", "Human")])
-        self.assertTrue(0 <= got[("Mouse", "Human")])
+        self.assertTrue(got[("Mouse", "Human")] >= 0)
 
         aligner = align.align_to_ref(ref_seq="Human")
         aln3 = aligner(self.seqs3)
@@ -156,43 +156,50 @@ class FastSlowDistTests(TestCase):
         fast_slow_dist = dist_app.fast_slow_dist(slow_calc="TN93")
         got = fast_slow_dist(aln3).to_dict()
         assert_allclose(got[("Human", "Mouse")], got[("Mouse", "Human")])
-        self.assertTrue(0 <= got[("Mouse", "Human")])
+        self.assertTrue(got[("Mouse", "Human")] >= 0)
 
         aligner = align.align_to_ref(ref_seq="Mouse")
         aln3 = aligner(self.seqs3)
         fast_slow_dist = dist_app.fast_slow_dist(slow_calc="GTR")
         got = fast_slow_dist(aln3).to_dict()
-        self.assertTrue(0 <= got[("Mouse", "Human")])
+        self.assertTrue(got[("Mouse", "Human")] >= 0)
         fast_slow_dist = dist_app.fast_slow_dist(slow_calc="TN93")
         got = fast_slow_dist(aln3).to_dict()
-        self.assertTrue(0 <= got[("Mouse", "Human")])
+        self.assertTrue(got[("Mouse", "Human")] >= 0)
 
         aligner = align.align_to_ref()
         aln3 = aligner(self.seqs4)
         fast_slow_dist = dist_app.fast_slow_dist(slow_calc="GTR")
         got = fast_slow_dist(aln3).to_dict()
-        self.assertTrue(0 <= got[("Human", "Opossum")])
+        self.assertTrue(got[("Human", "Opossum")] >= 0)
         fast_slow_dist = dist_app.fast_slow_dist(slow_calc="TN93")
         got = fast_slow_dist(aln3).to_dict()
-        self.assertTrue(0 <= got[("Human", "Opossum")])
+        self.assertTrue(got[("Human", "Opossum")] >= 0)
 
         aligner = align.align_to_ref(ref_seq="Human")
         aln3 = aligner(self.seqs4)
         fast_slow_dist = dist_app.fast_slow_dist(slow_calc="GTR")
         got = fast_slow_dist(aln3).to_dict()
-        self.assertTrue(0 <= got[("Human", "Opossum")])
+        self.assertTrue(got[("Human", "Opossum")] >= 0)
         fast_slow_dist = dist_app.fast_slow_dist(slow_calc="TN93")
         got = fast_slow_dist(aln3).to_dict()
-        self.assertTrue(0 <= got[("Human", "Opossum")])
+        self.assertTrue(got[("Human", "Opossum")] >= 0)
 
         aligner = align.align_to_ref(ref_seq="Opossum")
         aln3 = aligner(self.seqs4)
         fast_slow_dist = dist_app.fast_slow_dist(slow_calc="GTR")
         got = fast_slow_dist(aln3).to_dict()
-        self.assertTrue(0 <= got[("Human", "Opossum")])
+        self.assertTrue(got[("Human", "Opossum")] >= 0)
         fast_slow_dist = dist_app.fast_slow_dist(slow_calc="TN93")
         got = fast_slow_dist(aln3).to_dict()
-        self.assertTrue(0 <= got[("Human", "Opossum")])
+        self.assertTrue(got[("Human", "Opossum")] >= 0)
+
+        # now as a process
+        proc = align.align_to_ref() + dist_app.fast_slow_dist(
+            fast_calc="hamming", moltype="dna"
+        )
+        got = proc(self.seqs1)
+        self.assertEqual(got[("Human", "Rhesus")], 1)
 
         treestring = "(Human:0.2,Bandicoot:0.2)"
         aligner = align.progressive_align(model="WG01", guide_tree=treestring)
