@@ -15,7 +15,7 @@ __author__ = "Gavin Huttley"
 __copyright__ = "Copyright 2007-2020, The Cogent Project"
 __credits__ = ["Gavin Huttley"]
 __license__ = "BSD-3"
-__version__ = "2020.2.7a"
+__version__ = "2020.12.21a"
 __maintainer__ = "Gavin Huttley"
 __email__ = "Gavin.Huttley@anu.edu.au"
 __status__ = "Alpha"
@@ -34,9 +34,9 @@ class TestModel(TestCase):
             got,
             (
                 "model(type='model', sm='HKY85', tree=None, "
-                "name=None, sm_args=None, lf_args=None, "
+                "name=None, sm_args=None,\nlf_args=None, "
                 "time_het='max', param_rules=None, "
-                "opt_args=None, split_codons=False, "
+                "opt_args=None,\nsplit_codons=False, "
                 "show_progress=False, verbose=False)"
             ),
         )
@@ -105,6 +105,8 @@ class TestModel(TestCase):
 
     def test_model_hypothesis_result_repr(self):
         """result objects __repr__ and _repr_html_ methods work correctly"""
+        import re
+
         _data = {
             "Human": "ATGCGGCTCGCGGAGGCCGCGCTCGCGGAG",
             "Mouse": "ATGCCCGGCGCCAAGGCAGCGCTGGCGGAG",
@@ -119,10 +121,25 @@ class TestModel(TestCase):
         )
         hyp = evo_app.hypothesis(model1, model2)
         result = hyp(aln)
+        # check the p-val formatted as %.4f
+        pval = str(result).splitlines()[4].split()[-1]
+        self.assertTrue(re.search(r"\d\.\d+", pval) is not None)
         self.assertIsInstance(result.__repr__(), str)
         self.assertIsInstance(result._repr_html_(), str)
         self.assertIsInstance(result.null.__repr__(), str)
         self.assertIsInstance(result.null._repr_html_(), str)
+        aln = load_aligned_seqs("data/primate_brca1.fasta", moltype="dna")
+        aln = aln.take_seqs(["Human", "Rhesus", "Galago"])[2::3].omit_gap_pos()
+        model1 = evo_app.model(
+            "F81", opt_args=dict(max_evaluations=25, limit_action="ignore")
+        )
+        model2 = evo_app.model(
+            "HKY85", opt_args=dict(max_evaluations=100, limit_action="ignore")
+        )
+        hyp = evo_app.hypothesis(model1, model2)
+        result = hyp(aln)
+        pval = str(result).splitlines()[4].split()[-1]
+        self.assertTrue(re.search(r"[0-9\.]+e-\d+", pval) is not None)
 
     def test_hypothesis_str(self):
         """correct str representation"""
@@ -132,10 +149,10 @@ class TestModel(TestCase):
         got = str(hyp)
         expect = (
             "hypothesis(type='hypothesis', null='HKY85', "
-            "alternates=(model(type='model', sm='HKY85', tree=None, "
-            "name='hky85-max-het', sm_args=None, lf_args=None, "
+            "alternates=(model(type='model',\nsm='HKY85', tree=None, "
+            "name='hky85-max-het', sm_args=None, lf_args=None,\n"
             "time_het='max', param_rules=None, opt_args=None,"
-            " split_codons=False, show_progress=False, verbose=False),),"
+            " split_codons=False,\nshow_progress=False, verbose=False),),"
             " init_alt=None)"
         )
         self.assertEqual(got, expect)
