@@ -1,18 +1,24 @@
 #!/usr/bin/env python
+import json
 import os
+import pathlib
 import re
 import tempfile
 import unittest
 
+from tempfile import TemporaryDirectory
+
 from cogent3 import DNA, PROTEIN, RNA
 from cogent3 import STANDARD_CODON as CODON
 from cogent3 import (
+    get_format_suffixes,
     load_aligned_seqs,
     load_unaligned_seqs,
     make_aligned_seqs,
     make_seq,
     make_unaligned_seqs,
 )
+from cogent3.app.data_store import make_record_for_json
 from cogent3.core.alignment import (
     Alignment,
     ArrayAlignment,
@@ -26,12 +32,11 @@ __author__ = "Peter Maxwell, Gavin Huttley and Rob Knight"
 __copyright__ = "Copyright 2007-2020, The Cogent Project"
 __credits__ = ["Peter Maxwell", "Gavin Huttley", "Rob Knight"]
 __license__ = "BSD-3"
-__version__ = "2020.2.7a"
+__version__ = "2020.12.21a"
 __maintainer__ = "Gavin Huttley"
 __email__ = "gavin.huttley@anu.edu.au"
 __status__ = "Production"
 
-_compression = re.compile(r"\.(gz|bz2)$")
 base_path = os.path.dirname(os.path.dirname(__file__))
 data_path = os.path.join(base_path, "data")
 
@@ -100,6 +105,11 @@ class TestConstructorFunctions(unittest.TestCase):
         self.assertTrue("Human" in got.to_dict())
         self.assertEqual(got.info["source"], path)
 
+    def test_load_unaligned_seqs_no_format(self):
+        """test loading unaligned from file"""
+        with self.assertRaises(ValueError):
+            got = load_unaligned_seqs("somepath")
+
     def test_load_aligned_seqs(self):
         """test loading aligned from file"""
         path = os.path.join(data_path, "brca1_5.paml")
@@ -113,6 +123,89 @@ class TestConstructorFunctions(unittest.TestCase):
         self.assertEqual(got.moltype.label, "dna")
         self.assertIsInstance(got, Alignment)
 
+    def test_load_aligned_seqs_no_format(self):
+        """test loading unaligned from file"""
+        with self.assertRaises(ValueError):
+            got = load_aligned_seqs("somepath")
+
+    def test_load_unaligned_seqs_from_json(self):
+        """test loading an unaligned object from json file"""
+        with TemporaryDirectory(dir=".") as dirname:
+            json_path = os.path.join(dirname, "unaligned.json")
+            path = os.path.join(data_path, "brca1_5.paml")
+            unaligned = load_unaligned_seqs(path)
+            unaligned.write(json_path)
+
+            got = load_unaligned_seqs(json_path)
+            self.assertIsInstance(got, SequenceCollection)
+            self.assertEqual(got.to_dict(), unaligned.to_dict())
+            self.assertEqual(got.info["source"], path)
+            # tests json generated by make_record_for_json
+            uncompleted_record = make_record_for_json("delme", got, False)
+            uncompleted_record_path = os.path.join(dirname, "uncompleted_record.json")
+            completed_record = make_record_for_json("delme", got, True)
+            completed_record_path = os.path.join(dirname, "completed_record.json")
+            with open(uncompleted_record_path, "w") as out:
+                out.write(json.dumps(uncompleted_record))
+            with open(completed_record_path, "w") as out:
+                out.write(json.dumps(completed_record))
+            # tests when provided record json file is uncompleted
+            with self.assertRaises(TypeError):
+                load_unaligned_seqs(uncompleted_record_path)
+            # tests when provided record json is completed
+            got = load_unaligned_seqs(completed_record_path)
+            self.assertIsInstance(got, SequenceCollection)
+            self.assertEqual(got.to_dict(), unaligned.to_dict())
+            self.assertEqual(got.info["source"], path)
+
+    def test_load_aligned_seqs_from_json(self):
+        """tests loading an aligned object from json file"""
+        with TemporaryDirectory(dir=".") as dirname:
+            path = os.path.join(data_path, "brca1_5.paml")
+            alignment = load_aligned_seqs(path, array_align=False, moltype="dna")
+            alignment_json_path = os.path.join(dirname, "alignment.json")
+            alignment.write(alignment_json_path)
+            array_alignment = load_aligned_seqs(path, moltype="dna")
+            array_alignment_json_path = os.path.join(dirname, "array_alignment.json")
+            array_alignment.write(array_alignment_json_path)
+            # tests case Alignment
+            got = load_aligned_seqs(alignment_json_path)
+            self.assertIsInstance(got, Alignment)
+            self.assertEqual(got.moltype.label, "dna")
+            self.assertEqual(got.to_dict(), alignment.to_dict())
+            self.assertEqual(got.info["source"], path)
+            # tests case ArrayAlignment
+            got = load_aligned_seqs(array_alignment_json_path)
+            self.assertIsInstance(got, ArrayAlignment)
+            self.assertEqual(got.moltype.label, "dna")
+            self.assertEqual(got.to_dict(), array_alignment.to_dict())
+            self.assertEqual(got.info["source"], path)
+
+            # tests json generated by make_record_for_json
+            uncompleted_record = make_record_for_json("delme", got, False)
+            completed_record = make_record_for_json("delme", got, True)
+            uncompleted_record_path = os.path.join(dirname, "uncompleted_record.json")
+            completed_record_path = os.path.join(dirname, "completed_record.json")
+            with open(uncompleted_record_path, "w") as out:
+                out.write(json.dumps(uncompleted_record))
+            with open(completed_record_path, "w") as out:
+                out.write(json.dumps(completed_record))
+            # tests when provided record json file is uncompleted
+            with self.assertRaises(TypeError):
+                load_unaligned_seqs(uncompleted_record_path)
+            # tests when provided record json is completed
+            got = load_aligned_seqs(completed_record_path)
+            self.assertIsInstance(got, ArrayAlignment)
+            self.assertEqual(got.to_dict(), array_alignment.to_dict())
+            self.assertEqual(got.info["source"], path)
+            # tests wrong input json file
+            json_path = os.path.join(dirname, "unaligned.json")
+            path = os.path.join(data_path, "brca1_5.paml")
+            unaligned = load_unaligned_seqs(path)
+            unaligned.write(json_path)
+            with self.assertRaises(TypeError):
+                load_aligned_seqs(json_path)
+
 
 class ReadingWritingFileFormats(unittest.TestCase):
     """Testing ability to read file formats."""
@@ -121,16 +214,19 @@ class ReadingWritingFileFormats(unittest.TestCase):
         filename = os.path.join(data_path, filename)
         aln = load_aligned_seqs(filename, **kw)
         if test_write:
-            r = _compression.search(filename)
-            if r:
-                cmpr = filename[r.start() :]
-                suffix = filename[: r.start()].split(".")[-1]
-            else:
-                suffix = filename.split(".")[-1]
+            suffix, cmpr = get_format_suffixes(filename)
+            if not cmpr:
                 cmpr = ""
+            else:
+                cmpr = f".{cmpr}"
+
             fn = tempfile.mktemp(suffix="." + suffix + cmpr)
             aln.write(filename=fn)
             os.remove(fn)
+            # now use pathlib
+            fn = pathlib.Path(fn)
+            aln.write(filename=fn)
+            fn.unlink()
 
     def test_write_unknown_raises(self):
         """writing unknown format raises FileFormatError"""
