@@ -2,7 +2,9 @@
 """Unit tests for distance_transform.py functions.
 """
 
-from numpy import array, diag, ones, shape, sqrt
+from unittest import TestCase, main
+
+from numpy import array, ones, shape, sqrt
 
 from cogent3.maths.distance_transform import (
     binary_dist_chisq,
@@ -39,18 +41,19 @@ from cogent3.maths.distance_transform import (
     trans_specprof,
     zeros,
 )
-from cogent3.util.unit_test import TestCase, main
 
 
 __author__ = "Justin Kuczynski"
 __copyright__ = "Copyright 2007-2020, The Cogent Project"
 __contributors__ = ["Justin Kuczynski", "Zongzhi Liu", "Greg Caporaso"]
 __license__ = "BSD-3"
-__version__ = "2020.2.7a"
+__version__ = "2020.12.21a"
 __maintainer__ = "Justin Kuczynski"
 __email__ = "justinak@gmail.com"
 __status__ = "Prototype"
 
+from numpy.testing import assert_allclose, assert_equal
+
 
 class functionTests(TestCase):
     """Tests of top-level functions."""
@@ -88,17 +91,17 @@ class functionTests(TestCase):
         tests inputs of empty mtx, zeros, and results compared with calcs done
         by hand"""
 
-        self.assertFloatEqual(dist_canberra(self.zeromtx), zeros((4, 4), "d"))
+        assert_allclose(dist_canberra(self.zeromtx), zeros((4, 4), "d"))
 
         mtx1expected = array([[0.0, 46.2 / 52.2], [46.2 / 52.2, 0.0]], "d")
-        self.assertFloatEqual(dist_canberra(self.mtx1), mtx1expected)
+        assert_allclose(dist_canberra(self.mtx1), mtx1expected)
 
         sparse1exp = ones((self.sparse1.shape[0], self.sparse1.shape[0]))
         # remove diagonal
         sparse1exp[0, 0] = sparse1exp[1, 1] = sparse1exp[2, 2] = sparse1exp[3, 3] = 0.0
 
         sparse1exp[0, 1] = sparse1exp[1, 0] = (5.33 - 0.4) / (5.33 + 0.4)
-        self.assertFloatEqual(dist_canberra(self.sparse1), sparse1exp)
+        assert_allclose(dist_canberra(self.sparse1), sparse1exp)
 
     def test_dist_canberra_bug(self):
         i = array([[0, 0, 1], [0, 1, 1]])
@@ -107,7 +110,7 @@ class functionTests(TestCase):
         )
         expected = array([[0.0, d], [d, 0.0]])
         actual = dist_canberra(i)
-        self.assertFloatEqual(expected, actual)
+        assert_allclose(expected, actual)
 
     def test_dist_euclidean(self):
         """tests dist_euclidean
@@ -115,7 +118,7 @@ class functionTests(TestCase):
         tests inputs of empty mtx, zeros, and dense1 compared with calcs done
         by hand"""
 
-        self.assertFloatEqual(dist_euclidean(self.zeromtx), zeros((4, 4), "d"))
+        assert_allclose(dist_euclidean(self.zeromtx), zeros((4, 4), "d"))
 
         dense1expected = array(
             [
@@ -125,7 +128,7 @@ class functionTests(TestCase):
             ],
             "d",
         )
-        self.assertFloatEqual(dist_euclidean(self.dense1), dense1expected)
+        assert_allclose(dist_euclidean(self.dense1), dense1expected)
 
     def test_dist_gower(self):
         """tests dist_gower
@@ -133,10 +136,10 @@ class functionTests(TestCase):
         tests inputs of empty mtx, zeros, and results compared with calcs done
         by hand"""
 
-        self.assertFloatEqual(dist_gower(self.zeromtx), zeros((4, 4), "d"))
+        assert_allclose(dist_gower(self.zeromtx), zeros((4, 4), "d"))
 
         mtx1expected = array([[0.0, 2.0], [2.0, 0.0]], "d")
-        self.assertFloatEqual(dist_gower(self.mtx1), mtx1expected)
+        assert_allclose(dist_gower(self.mtx1), mtx1expected)
 
         sparse1expected = array(
             [
@@ -147,7 +150,7 @@ class functionTests(TestCase):
             ],
             "d",
         )
-        self.assertFloatEqual(dist_gower(self.sparse1), sparse1expected)
+        assert_allclose(dist_gower(self.sparse1), sparse1expected)
 
     def test_dist_manhattan(self):
         """tests dist_manhattan
@@ -155,20 +158,20 @@ class functionTests(TestCase):
         tests inputs of empty mtx, zeros, and dense1 compared with calcs done
         by hand"""
 
-        self.assertFloatEqual(dist_manhattan(self.zeromtx), zeros((4, 4), "d"))
+        assert_allclose(dist_manhattan(self.zeromtx), zeros((4, 4), "d"))
 
         dense1expected = array(
             [[0.0, 5.0, 019.9], [5.0, 0.0, 24.9], [19.9, 24.90, 0.0]], "d"
         )
-        self.assertFloatEqual(dist_manhattan(self.dense1), dense1expected)
+        assert_allclose(dist_manhattan(self.dense1), dense1expected)
 
     def test_dist_abund_jaccard(self):
         """dist_abund_jaccard should compute distances for dense1 and mtx1"""
         mtx1_expected = array([[0, 0.25], [0.25, 0]], "d")
-        self.assertEqual(dist_abund_jaccard(self.mtx1), mtx1_expected)
+        assert_equal(dist_abund_jaccard(self.mtx1), mtx1_expected)
 
         dense1_expected = zeros((3, 3), "d")
-        self.assertEqual(dist_abund_jaccard(self.dense1), dense1_expected)
+        assert_equal(dist_abund_jaccard(self.dense1), dense1_expected)
 
         sparse1_expected = array(
             [
@@ -179,7 +182,7 @@ class functionTests(TestCase):
             ],
             "d",
         )
-        self.assertEqual(dist_abund_jaccard(self.sparse1), sparse1_expected)
+        assert_equal(dist_abund_jaccard(self.sparse1), sparse1_expected)
 
     def test_dist_morisita_horn(self):
         """tests dist_morisita_horn
@@ -187,11 +190,11 @@ class functionTests(TestCase):
         tests inputs of empty mtx, zeros, and dense1 compared with calcs done
         by hand"""
 
-        self.assertFloatEqual(dist_morisita_horn(self.zeromtx), zeros((4, 4), "d"))
+        assert_allclose(dist_morisita_horn(self.zeromtx), zeros((4, 4), "d"))
 
         a = 1 - 2 * 69.3 / (26 / 16.0 * 23.1 * 4)
         mtx1expected = array([[0, a], [a, 0]], "d")
-        self.assertFloatEqual(dist_morisita_horn(self.mtx1), mtx1expected)
+        assert_allclose(dist_morisita_horn(self.mtx1), mtx1expected)
 
     def test_dist_bray_curtis(self):
         """tests dist_bray_curtis
@@ -199,10 +202,10 @@ class functionTests(TestCase):
         tests inputs of empty mtx, zeros, and mtx1 compared with calcs done
         by hand"""
 
-        self.assertFloatEqual(dist_manhattan(self.zeromtx), zeros((4, 4) * 1, "d"))
+        assert_allclose(dist_manhattan(self.zeromtx), zeros((4, 4) * 1, "d"))
 
         mtx1expected = array([[0, 21.1 / 27.1], [21.1 / 27.1, 0]], "d")
-        self.assertFloatEqual(dist_bray_curtis(self.mtx1), mtx1expected)
+        assert_allclose(dist_bray_curtis(self.mtx1), mtx1expected)
 
     def test_dist_bray_curtis_faith(self):
         """tests dist_bray_curtis_faith
@@ -210,10 +213,10 @@ class functionTests(TestCase):
         tests inputs of empty mtx, zeros, and mtx1 compared with calcs done
         by hand"""
 
-        self.assertFloatEqual(dist_manhattan(self.zeromtx), zeros((4, 4) * 1, "d"))
+        assert_allclose(dist_manhattan(self.zeromtx), zeros((4, 4) * 1, "d"))
 
         mtx1expected = array([[0, 21.1 / 27.1], [21.1 / 27.1, 0]], "d")
-        self.assertFloatEqual(dist_bray_curtis_faith(self.mtx1), mtx1expected)
+        assert_allclose(dist_bray_curtis_faith(self.mtx1), mtx1expected)
 
     def test_dist_soergel(self):
         """tests dist_soergel
@@ -221,13 +224,13 @@ class functionTests(TestCase):
         tests inputs of empty mtx, zeros, and dense1 compared with calcs done
         by hand/manhattan dist"""
 
-        self.assertFloatEqual(dist_soergel(self.zeromtx), zeros((4, 4) * 1, "d"))
+        assert_allclose(dist_soergel(self.zeromtx), zeros((4, 4) * 1, "d"))
 
         dense1expected = dist_manhattan(self.dense1)
         dense1norm = array([[1, 8, 23], [8, 1, 27], [23, 27, 1]], "d")
         dense1expected /= dense1norm
 
-        self.assertFloatEqual(dist_soergel(self.dense1), dense1expected)
+        assert_allclose(dist_soergel(self.dense1), dense1expected)
 
     def test_dist_kulczynski(self):
         """tests dist_kulczynski
@@ -235,7 +238,7 @@ class functionTests(TestCase):
         tests inputs of empty mtx, zeros, and mtx1 compared with calcs done
         by hand"""
 
-        self.assertFloatEqual(dist_kulczynski(self.zeromtx), zeros((4, 4) * 1, "d"))
+        assert_allclose(dist_kulczynski(self.zeromtx), zeros((4, 4) * 1, "d"))
 
         mtx1expected = array(
             [
@@ -245,27 +248,27 @@ class functionTests(TestCase):
             "d",
         )
 
-        self.assertFloatEqual(dist_kulczynski(self.mtx1), mtx1expected)
+        assert_allclose(dist_kulczynski(self.mtx1), mtx1expected)
 
     def test_dist_pearson(self):
         """tests dist_pearson
 
         tests inputs of empty mtx, zeros, mtx compared with calcs done
-        by hand, and an example from 
+        by hand, and an example from
         http://davidmlane.com/hyperstat/A56626.html
         """
 
-        self.assertFloatEqual(dist_pearson(self.zeromtx), zeros((4, 4), "d"))
+        assert_allclose(dist_pearson(self.zeromtx), zeros((4, 4), "d"))
 
         mtx1expected = array([[0, 0], [0, 0]], "d")
-        self.assertFloatEqual(dist_pearson(self.mtx1), mtx1expected)
+        assert_allclose(dist_pearson(self.mtx1), mtx1expected)
 
         # example 1 from http://davidmlane.com/hyperstat/A56626.html
         ex1 = array([[1, 2, 3], [2, 5, 6]], "d")
         ex1res = 1 - 4.0 / sqrt(2.0 * (8 + 2.0 / 3.0))
         ex1expected = array([[0, ex1res], [ex1res, 0]], "d")
 
-        self.assertFloatEqual(dist_pearson(ex1), ex1expected)
+        assert_allclose(dist_pearson(ex1), ex1expected)
 
     def test_dist_spearman_approx(self):
         """tests dist_spearman_approx
@@ -273,9 +276,7 @@ class functionTests(TestCase):
         tests inputs of empty mtx, zeros, and an example from wikipedia
         """
 
-        self.assertFloatEqual(
-            dist_spearman_approx(self.zeromtx), zeros((4, 4) * 1, "d")
-        )
+        assert_allclose(dist_spearman_approx(self.zeromtx), zeros((4, 4) * 1, "d"))
 
         # ex1 from wikipedia Spearman's_rank_correlation_coefficient 20jan2009
         ex1 = array(
@@ -287,14 +288,14 @@ class functionTests(TestCase):
         )
         ex1res = 6.0 * 194.0 / (10.0 * 99.0)
         ex1expected = array([[0, ex1res], [ex1res, 0]], "d")
-        self.assertFloatEqual(dist_spearman_approx(ex1), ex1expected)
+        assert_allclose(dist_spearman_approx(ex1), ex1expected)
 
     # now binary fns
     def test_binary_dist_otu_gain(self):
         """ binary OTU gain functions as expected """
         actual = binary_dist_otu_gain(self.input_binary_dist_otu_gain1)
         expected = array([[0, 1, 2, 2], [1, 0, 2, 1], [1, 1, 0, 1], [1, 0, 1, 0]])
-        self.assertEqual(actual, expected)
+        assert_equal(actual, expected)
 
     def test_binary_dist_chisq(self):
         """tests binary_dist_chisq
@@ -302,10 +303,10 @@ class functionTests(TestCase):
         tests inputs of empty mtx, zeros, and mtx1 compared with calcs done
         by hand"""
 
-        self.assertFloatEqual(binary_dist_chisq(self.zeromtx), zeros((4, 4), "d"))
+        assert_allclose(binary_dist_chisq(self.zeromtx), zeros((4, 4), "d"))
 
         mtx1expected = array([[0, sqrt(9 / 8.0)], [sqrt(9 / 8.0), 0]], "d")
-        self.assertFloatEqual(binary_dist_chisq(self.mtx1), mtx1expected)
+        assert_allclose(binary_dist_chisq(self.mtx1), mtx1expected)
 
     def test_binary_dist_chord(self):
         """tests binary_dist_chord
@@ -313,7 +314,7 @@ class functionTests(TestCase):
         tests inputs of empty mtx, zeros, and results compared with calcs done
         by hand"""
 
-        self.assertFloatEqual(binary_dist_chord(self.zeromtx), zeros((4, 4), "d"))
+        assert_allclose(binary_dist_chord(self.zeromtx), zeros((4, 4), "d"))
 
         mtx1expected = array(
             [
@@ -322,7 +323,7 @@ class functionTests(TestCase):
             ],
             "d",
         )
-        self.assertFloatEqual(binary_dist_chord(self.mtx1), mtx1expected)
+        assert_allclose(binary_dist_chord(self.mtx1), mtx1expected)
 
     def test_binary_dist_lennon(self):
         """tests binary_dist_lennon
@@ -330,14 +331,14 @@ class functionTests(TestCase):
         tests inputs of empty mtx, zeros, and results compared with calcs done
         by hand"""
 
-        self.assertFloatEqual(binary_dist_lennon(self.zeromtx), zeros((4, 4), "d"))
+        assert_allclose(binary_dist_lennon(self.zeromtx), zeros((4, 4), "d"))
 
         mtxa = array([[5.2, 9, 0.2], [0, 99, 1], [0, 0.0, 8233.1]], "d")
-        self.assertFloatEqual(binary_dist_lennon(mtxa), zeros((3, 3), "d"))
+        assert_allclose(binary_dist_lennon(mtxa), zeros((3, 3), "d"))
 
         mtxb = array([[5.2, 0, 0.2, 9.2], [0, 0, 0, 1], [0, 3.2, 0, 8233.1]], "d")
         mtxbexpected = array([[0, 0, 0.5], [0, 0, 0], [0.5, 0, 0]], "d")
-        self.assertFloatEqual(binary_dist_lennon(mtxb), mtxbexpected)
+        assert_allclose(binary_dist_lennon(mtxb), mtxbexpected)
 
     def test_binary_dist_pearson(self):
         """tests binary_dist_pearson
@@ -345,9 +346,9 @@ class functionTests(TestCase):
         tests inputs of empty mtx, zeros, and dense1 compared with calcs done
         by hand"""
 
-        self.assertFloatEqual(binary_dist_pearson(self.zeromtx), zeros((4, 4), "d"))
+        assert_allclose(binary_dist_pearson(self.zeromtx), zeros((4, 4), "d"))
 
-        self.assertFloatEqual(binary_dist_pearson(self.dense1), zeros((3, 3)))
+        assert_allclose(binary_dist_pearson(self.dense1), zeros((3, 3)))
 
     def test_binary_dist_jaccard(self):
         """tests binary_dist_jaccard
@@ -355,19 +356,19 @@ class functionTests(TestCase):
         tests inputs of empty mtx, zeros, and sparse1 compared with calcs done
         by hand"""
 
-        self.assertFloatEqual(binary_dist_jaccard(self.zeromtx), zeros((4, 4), "d"))
+        assert_allclose(binary_dist_jaccard(self.zeromtx), zeros((4, 4), "d"))
 
         sparse1expected = array(
             [[0, 0, 1.0, 1.0], [0, 0, 1, 1], [1, 1, 0, 1], [1, 1, 1, 0]], "d"
         )
-        self.assertFloatEqual(binary_dist_jaccard(self.sparse1), sparse1expected)
+        assert_allclose(binary_dist_jaccard(self.sparse1), sparse1expected)
 
         sparse1expected = dist_manhattan(self.sparse1.astype(bool))
         sparse1norm = array(
             [[1, 1, 2, 1], [1, 1, 2, 1], [2, 2, 1, 1], [1, 1, 1, 100]], "d"
         )
         sparse1expected /= sparse1norm
-        self.assertFloatEqual(binary_dist_jaccard(self.sparse1), sparse1expected)
+        assert_allclose(binary_dist_jaccard(self.sparse1), sparse1expected)
 
     def test_binary_dist_ochiai(self):
         """tests binary_dist_ochiai
@@ -375,10 +376,10 @@ class functionTests(TestCase):
         tests inputs of empty mtx, zeros, and mtx1 compared with calcs done
         by hand"""
 
-        self.assertFloatEqual(binary_dist_ochiai(self.zeromtx), zeros((4, 4), "d"))
+        assert_allclose(binary_dist_ochiai(self.zeromtx), zeros((4, 4), "d"))
 
         mtx1expected = array([[0, 1 - 1 / sqrt(2.0)], [1 - 1 / sqrt(2.0), 0]], "d")
-        self.assertFloatEqual(binary_dist_ochiai(self.mtx1), mtx1expected)
+        assert_allclose(binary_dist_ochiai(self.mtx1), mtx1expected)
 
     def test_binary_dist_hamming(self):
         """tests binary_dist_hamming
@@ -386,10 +387,10 @@ class functionTests(TestCase):
         tests inputs of empty mtx, zeros, and mtx1 compared with calcs done
         by hand"""
 
-        self.assertFloatEqual(binary_dist_hamming(self.zeromtx), zeros((4, 4), "d"))
+        assert_allclose(binary_dist_hamming(self.zeromtx), zeros((4, 4), "d"))
 
         mtx1expected = array([[0, 1], [1, 0]], "d")
-        self.assertFloatEqual(binary_dist_hamming(self.mtx1), mtx1expected)
+        assert_allclose(binary_dist_hamming(self.mtx1), mtx1expected)
 
     def test_binary_dist_sorensen_dice(self):
         """tests binary_dist_sorensen_dice
@@ -397,18 +398,16 @@ class functionTests(TestCase):
         tests inputs of empty mtx, zeros, and mtx1 compared with calcs done
         by hand"""
 
-        self.assertFloatEqual(
-            binary_dist_sorensen_dice(self.zeromtx), zeros((4, 4), "d")
-        )
+        assert_allclose(binary_dist_sorensen_dice(self.zeromtx), zeros((4, 4), "d"))
 
         mtx1expected = array([[0, 1 / 3.0], [1 / 3.0, 0]], "d")
-        self.assertFloatEqual(binary_dist_sorensen_dice(self.mtx1), mtx1expected)
+        assert_allclose(binary_dist_sorensen_dice(self.mtx1), mtx1expected)
 
         sparse1expected = array(
             [[0, 0, 1.0, 1.0], [0, 0, 1, 1], [1, 1, 0, 1], [1, 1, 1, 0]], "d"
         )
 
-        self.assertFloatEqual(binary_dist_sorensen_dice(self.sparse1), sparse1expected)
+        assert_allclose(binary_dist_sorensen_dice(self.sparse1), sparse1expected)
 
     def test_binary_dist_euclidean(self):
         """tests binary_dist_euclidean
@@ -424,9 +423,9 @@ class functionTests(TestCase):
         sparse1expected[2, 3] = 1.0
         sparse1expected = self.get_sym_mtx_from_uptri(sparse1expected)
 
-        self.assertFloatEqual(binary_dist_euclidean(self.dense1), dense1expected)
-        self.assertFloatEqual(binary_dist_euclidean(self.sparse1), sparse1expected)
-        self.assertFloatEqual(binary_dist_euclidean(self.zeromtx), zeros((4, 4), "d"))
+        assert_allclose(binary_dist_euclidean(self.dense1), dense1expected)
+        assert_allclose(binary_dist_euclidean(self.sparse1), sparse1expected)
+        assert_allclose(binary_dist_euclidean(self.zeromtx), zeros((4, 4), "d"))
 
     # zj's stuff
     def test_chord_transform(self):
@@ -438,12 +437,12 @@ class functionTests(TestCase):
             [0.90453403, 0.30151134, 0.30151134],
         ]
         res = trans_chord(self.mat_test)
-        self.assertFloatEqual(res, exp)
+        assert_allclose(res, exp)
 
     def test_chord_dist(self):
         """dist_chord should return the exp result."""
 
-        self.assertFloatEqual(dist_chord(self.zeromtx), zeros((4, 4), "d"))
+        assert_allclose(dist_chord(self.zeromtx), zeros((4, 4), "d"))
 
         exp = [
             [0.0, 0.46662021, 0.72311971],
@@ -451,7 +450,7 @@ class functionTests(TestCase):
             [0.72311971, 0.62546036, 0.0],
         ]
         dist = dist_chord(self.mat_test)
-        self.assertFloatEqual(dist, exp)
+        assert_allclose(dist, exp)
 
     def test_chisq_transform(self):
         """trans_chisq should return the exp result in the ref paper."""
@@ -461,12 +460,12 @@ class functionTests(TestCase):
             [1.01418511, 0.36514837, 0.3380617],
         ]
         res_m = trans_chisq(self.mat_test)
-        self.assertFloatEqual(res_m, exp_m)
+        assert_allclose(res_m, exp_m)
 
     def test_chisq_distance(self):
         """dist_chisq should return the exp result."""
 
-        self.assertFloatEqual(dist_chisq(self.zeromtx), zeros((4, 4), "d"))
+        assert_allclose(dist_chisq(self.zeromtx), zeros((4, 4), "d"))
 
         exp_d = [
             [0.0, 0.4910521, 0.78452291],
@@ -474,7 +473,7 @@ class functionTests(TestCase):
             [0.78452291, 0.69091002, 0.0],
         ]
         res_d = dist_chisq(self.mat_test)
-        self.assertFloatEqual(res_d, exp_d)
+        assert_allclose(res_d, exp_d)
 
     def test_hellinger_transform(self):
         """dist_hellinger should return the exp result in the ref paper."""
@@ -484,12 +483,12 @@ class functionTests(TestCase):
             [0.77459667, 0.4472136, 0.4472136],
         ]
         res = trans_hellinger(self.mat_test)
-        self.assertFloatEqual(res, exp)
+        assert_allclose(res, exp)
 
     def test_hellinger_distance(self):
         """dist_hellinger should return the exp result."""
 
-        self.assertFloatEqual(dist_hellinger(self.zeromtx), zeros((4, 4), "d"))
+        assert_allclose(dist_hellinger(self.zeromtx), zeros((4, 4), "d"))
 
         exp = [
             [0.0, 0.23429661, 0.38175149],
@@ -497,18 +496,18 @@ class functionTests(TestCase):
             [0.38175149, 0.32907422, 0.0],
         ]
         dist = dist_hellinger(self.mat_test)
-        self.assertFloatEqual(dist, exp)
+        assert_allclose(dist, exp)
 
     def test_species_profile_transform(self):
         """trans_specprof should return the exp result."""
         exp = [[0.25, 0.25, 0.5], [0.28571429, 0.42857143, 0.28571429], [0.6, 0.2, 0.2]]
         res = trans_specprof(self.mat_test)
-        self.assertFloatEqual(res, exp)
+        assert_allclose(res, exp)
 
     def test_species_profile_distance(self):
         """dist_specprof should return the exp result."""
 
-        self.assertFloatEqual(dist_specprof(self.zeromtx), zeros((4, 4), "d"))
+        assert_allclose(dist_specprof(self.zeromtx), zeros((4, 4), "d"))
 
         exp = [
             [0.0, 0.28121457, 0.46368092],
@@ -516,17 +515,17 @@ class functionTests(TestCase):
             [0.46368092, 0.39795395, 0.0],
         ]
         dist = dist_specprof(self.mat_test)
-        self.assertFloatEqual(dist, exp)
+        assert_allclose(dist, exp)
 
     def test_dist_bray_curtis_magurran1(self):
         """ zero values should return zero dist, or 1 with nonzero samples"""
         res = dist_bray_curtis_magurran(numpy.array([[0, 0, 0], [0, 0, 0], [1, 1, 1]]))
-        self.assertFloatEqual(res, numpy.array([[0, 0, 1], [0, 0, 1], [1, 1, 0]]))
+        assert_allclose(res, numpy.array([[0, 0, 1], [0, 0, 1], [1, 1, 0]]))
 
     def test_dist_bray_curtis_magurran2(self):
         """ should match hand-calculated values"""
         res = dist_bray_curtis_magurran(numpy.array([[1, 4, 3], [1, 3, 5], [0, 2, 0]]))
-        self.assertFloatEqual(
+        assert_allclose(
             res,
             numpy.array(
                 [
@@ -582,7 +581,7 @@ class functionTests(TestCase):
     # for i in range(len(dist_results)):
     # for j in range(i):
     # try:
-    # self.assertFloatEqual(dist_results[i], dist_results[j])
+    # assert_allclose(dist_results[i], dist_results[j])
     # except:
     # pass # should not be equal, so catch error and proceed
     # else:
